@@ -942,6 +942,19 @@ gint status;
 }
 
 
+//#1960755 add refresh button
+static void register_panel_cb_filter_refresh(GtkWidget *widget, gpointer user_data)
+{
+struct register_panel_data *data;
+
+	DB( g_print("\n[register] filter_refresh\n") );
+	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
+
+	register_panel_collect_filtered_txn(data->LV_ope, FALSE);
+	register_panel_listview_populate(data->LV_ope);
+}
+
+
 static void register_panel_cb_filter_reset(GtkWidget *widget, gpointer user_data)
 {
 struct register_panel_data *data;
@@ -2636,6 +2649,9 @@ gint row;
 	gtk_window_set_title (GTK_WINDOW (window), data->wintitle);
 	gtk_window_set_icon_name(GTK_WINDOW (window), ICONNAME_HB_OPE_SHOW );
 
+	//#1965594
+	gtk_window_set_transient_for (GTK_WINDOW (window), GTK_WINDOW (GLOBALS->mainwindow));
+	
 	// connect our dispose function
 	g_signal_connect (window, "delete-event",
 		G_CALLBACK (register_panel_dispose), (gpointer)data);
@@ -2737,11 +2753,16 @@ gint row;
 	data->BT_reset = widget;
 	gtk_grid_attach (GTK_GRID(table), widget, row, 0, 1, 1);
 
+	row++;
+	widget = make_image_button(ICONNAME_HB_REFRESH, _("Refresh results"));
+	data->BT_refresh = widget;
+	gtk_grid_attach (GTK_GRID(table), widget, row, 0, 1, 1);
+
 	row++;
 	widget = make_image_button(ICONNAME_HB_FILTER, _("Open the list filter"));
 	data->BT_filter = widget;
 	gtk_grid_attach (GTK_GRID(table), widget, row, 0, 1, 1);
-	
+
 	row++;
 	//TRANSLATORS: this is for Euro specific users, a toggle to display in 'Minor' currency
 	widget = gtk_check_button_new_with_mnemonic (_("Euro _minor"));
@@ -2917,8 +2938,9 @@ gint row;
 
 	g_signal_connect (data->CM_future, "toggled", G_CALLBACK (register_panel_cb_filter_daterange), NULL);
 
-	g_signal_connect (data->BT_reset , "clicked", G_CALLBACK (register_panel_cb_filter_reset), NULL);
-	g_signal_connect (data->BT_filter, "clicked", G_CALLBACK (register_panel_action_editfilter), (gpointer)data);
+	g_signal_connect (data->BT_reset  , "clicked", G_CALLBACK (register_panel_cb_filter_reset), NULL);
+	g_signal_connect (data->BT_refresh, "clicked", G_CALLBACK (register_panel_cb_filter_refresh), NULL);
+	g_signal_connect (data->BT_filter , "clicked", G_CALLBACK (register_panel_action_editfilter), (gpointer)data);
 	
 	g_signal_connect (data->CM_minor , "toggled", G_CALLBACK (register_panel_toggle_minor), NULL);
 	
