@@ -348,7 +348,7 @@ gchar *secondtext;
 static void ui_mainwindow_action_defcurrency(void)
 {
 	ui_cur_manage_dialog();
-	ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_SENSITIVE+UF_REFRESHALL));
+	ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_TITLE+UF_SENSITIVE+UF_REFRESHALL));
 }
 
 
@@ -361,13 +361,13 @@ static void ui_mainwindow_action_defaccount(void)
 	account_compute_balances ();
 	ui_hub_account_populate(GLOBALS->mainwindow, NULL);
 
-	ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_SENSITIVE));
+	ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_TITLE+UF_SENSITIVE));
 }
 
 static void ui_mainwindow_action_defpayee(void)
 {
 	ui_pay_manage_dialog();
-	ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_SENSITIVE));
+	ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_TITLE+UF_SENSITIVE));
 }
 
 static void ui_mainwindow_action_defcategory(void)
@@ -375,7 +375,7 @@ static void ui_mainwindow_action_defcategory(void)
 	ui_cat_manage_dialog();
 	//todo:why refresh upcoming here??
 	//ui_mainwindow_populate_upcoming(GLOBALS->mainwindow, NULL);
-	ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_SENSITIVE+UF_REFRESHALL));
+	ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_TITLE+UF_SENSITIVE+UF_REFRESHALL));
 }
 
 
@@ -395,7 +395,7 @@ GtkTreeModel *model;
 
 	ui_hub_scheduled_populate(GLOBALS->mainwindow, NULL);
 
-	ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_SENSITIVE));
+	ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_TITLE+UF_SENSITIVE));
 }
 
 
@@ -408,13 +408,13 @@ static void ui_mainwindow_action_defarchive(void)
 static void ui_mainwindow_action_defbudget(void)
 {
 	ui_bud_manage_dialog();
-	ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_SENSITIVE));
+	ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_TITLE+UF_SENSITIVE));
 }
 
 static void ui_mainwindow_action_defbudgettable(void)
 {
 	ui_bud_tabview_manage_dialog();
-	ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_SENSITIVE));
+	ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_TITLE+UF_SENSITIVE));
 }
 
 static void ui_mainwindow_action_defassign(void)
@@ -422,7 +422,7 @@ static void ui_mainwindow_action_defassign(void)
 
 	ui_asg_manage_dialog();
 
-	ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_SENSITIVE));
+	ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_TITLE+UF_SENSITIVE));
 }
 
 
@@ -431,7 +431,7 @@ static void ui_mainwindow_action_deftag(void)
 
 	ui_tag_manage_dialog();
 
-	ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_SENSITIVE));
+	ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_TITLE+UF_SENSITIVE));
 }
 
 
@@ -584,7 +584,7 @@ static void ui_mainwindow_action_vehiclecost(void)
 	repvehicle_window_new();
 }
 
-static void ui_mainwindow_action_import(GtkAction *action)
+static void ui_mainwindow_action_import(void)
 {
 /*const gchar *name;
 gint filetype = FILETYPE_UNKNOWN;
