@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2021 Maxime DOYEN
+ *  Copyright (C) 1995-2022 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -64,6 +64,7 @@ enum {
 	THTEXT
 };
 
+
 enum colmap
 {
 	CHART_COLMAP_HOMEBANK,
@@ -74,8 +75,13 @@ enum colmap
 	CHART_COLMAP_OFFICE2013,
 	CHART_COLMAP_ANALYTICS,
 	CHART_COLMAP_YNAB,
+	CHART_COLMAP_QUICKEN2017,
+	CHART_COLMAP_MINT,
+	CHART_COLMAP_MATERIAL,
+	CHART_COLMAP_NORD,
 };
 
+
 enum {
 	CHART_FONT_SIZE_TITLE,
 	CHART_FONT_SIZE_SUBTITLE,
@@ -95,6 +101,10 @@ extern struct rgbcol office2013_colors[];
 extern struct rgbcol sap_colors[];
 extern struct rgbcol homebank_colors[];
 extern struct rgbcol ynab_colors[];
+extern struct rgbcol quicken2017_colors[];
+extern struct rgbcol mint_colors[];
+extern struct rgbcol material_colors[];
+extern struct rgbcol nord_colors[];
 
 extern int money_nbcolors;
 extern int quicken_nbcolors;
@@ -104,6 +114,10 @@ extern int office2013_nbcolors;
 extern int sap_nbcolors;
 extern int homebank_nbcolors;
 extern int ynab_nbcolors;
+extern int quicken2017_nbcolors;
+extern int mint_nbcolors;
+extern int material_nbcolors;
+extern int nord_nbcolors;
 
 void chart_color_global_default(void);
 
