@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2021 Maxime DOYEN
+ *  Copyright (C) 1995-2022 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -27,6 +27,8 @@
 #include "gtk-chart-colors.h"
 #include "gtk-chart.h"
 
+//TODO: move this
+#include "list-report.h"
 
 /****************************************************************************/
 /* Debug macros                                                             */
@@ -41,10 +43,18 @@
 #define DBC(x);
 //#define DBC(x) (x);
 
+//graph
+#define DBG(x);
+//#define DBG(x) (x);
+
 //DB dynamics
 #define DBD(x);
 //#define DBD(x) (x);
 
+//tooltip
+#define DBT(x);
+//#define DBT(x) (x);
+
 
 //TODO: ugly hack for total line
 #define LST_REPDIST_POS_TOTAL G_MAXINT
@@ -64,7 +74,9 @@ const double dashed3[] = {3.0};
 
 static void chart_set_font_size(GtkChart *chart, PangoLayout *layout, gint font_size);
 static gchar *chart_print_int(GtkChart *chart, gint value);
+static gchar *chart_print_scalerate(GtkChart *chart, gdouble value);
 static gboolean drawarea_full_redraw(GtkWidget *widget, gpointer user_data);
+static void chart_clear(GtkChart *chart);
 
 
 /* = = = = = = = = = = = = = = = = */
@@ -110,6 +122,7 @@ double scale = PANGO_SCALE_MEDIUM;
 	pango_attr_list_insert (attrs, attr);
 
 	pango_layout_set_attributes (layout, attrs);
+
 	pango_layout_set_font_description (layout, chart->pfd);
 
 	//pango_attribute_destroy(attr);
@@ -160,10 +173,17 @@ double lobound, hibound;
 	drawctx->range = chart->rawmax - chart->rawmin;
 	gint maxticks = MIN(10,floor(drawctx->graph.height / (drawctx->font_h * 2)));
 
+	if( chart->type == CHART_TYPE_STACK100 )
+	{
+		lobound = 0;
+		hibound = 100;
+		drawctx->range = 100;
+	}
+
 	DBC( g_print(" raw :: [%.2f - %.2f] range=%.2f\n", chart->rawmin, chart->rawmax, drawctx->range) );
 	DBC( g_print(" raw :: maxticks=%d (%g / (%g*2))\n", maxticks, drawctx->graph.height, drawctx->font_h) );
-
 	DBC( g_print("\n") );
+
 	drawctx->unit  = CalculateStepSize((hibound-lobound), maxticks);
 	drawctx->min   = -drawctx->unit * ceil(-lobound/drawctx->unit);
 	drawctx->max   = drawctx->unit * ceil(hibound/drawctx->unit);
@@ -173,17 +193,22 @@ double lobound, hibound;
 	DBC( g_print(" end :: interval=%.2f, ticks=%d\n", drawctx->unit, drawctx->div) );
 	DBC( g_print(" end :: [%.2f - %.2f], range=%.2f\n", drawctx->min, drawctx->max, drawctx->range) );
 
+	DBC( g_print("[column] end compute range\n\n") );
+
 }
 
 
-
-
 static void colchart_calculation(GtkChart *chart, HbtkDrawContext *drawctx)
 {
 gint blkw, maxvisi;
+gint nb_items;
 
 	DBC( g_print("\n[colchart] calculation\n") );
 
+	nb_items = chart->nb_items;
+	if( chart->type == CHART_TYPE_STACK || chart->type == CHART_TYPE_STACK100)
+		nb_items = chart->nb_cols;
+
 	/* from fusionchart
 	the bar has a default width of 41
 	min space is 3 and min barw is 8
@@ -200,16 +225,16 @@ gint blkw, maxvisi;
 		//minvisi = floor(chart->graph.width / (GTK_CHART_MINBARW+3) );
 		maxvisi = floor(drawctx->graph.width / (GTK_CHART_MAXBARW+3) );
 
-		//DB( g_print(" width=%.2f, nb=%d, minvisi=%d, maxvisi=%d\n", chart->graph.width, chart->nb_items, minvisi, maxvisi) );
+		//DBC( g_print(" width=%.2f, nb=%d, minvisi=%d, maxvisi=%d\n", chart->graph.width, nb_items, minvisi, maxvisi) );
 
-		if( chart->nb_items <= maxvisi )
+		if( nb_items <= maxvisi )
 		{
 			drawctx->barw = GTK_CHART_MAXBARW;
-			blkw = GTK_CHART_MAXBARW + ( drawctx->graph.width - (chart->nb_items*GTK_CHART_MAXBARW) ) / chart->nb_items;
+			blkw = GTK_CHART_MAXBARW + ( drawctx->graph.width - (nb_items*GTK_CHART_MAXBARW) ) / nb_items;
 		}
 		else
 		{
-			blkw = MAX(GTK_CHART_MINBARW, floor(drawctx->graph.width / chart->nb_items));
+			blkw = MAX(GTK_CHART_MINBARW, floor(drawctx->graph.width / nb_items));
 			drawctx->barw = blkw - 3;
 		}
 	}
@@ -221,7 +246,7 @@ gint blkw, maxvisi;
 
 	drawctx->blkw = blkw;
 	drawctx->visible = drawctx->graph.width / blkw;
-	drawctx->visible = MIN(drawctx->visible, chart->nb_items);
+	drawctx->visible = MIN(drawctx->visible, nb_items);
 
 	DBC( g_print(" blkw=%.2f, barw=%.2f, visible=%d\n", drawctx->blkw, drawctx->barw, drawctx->visible) );
 
@@ -247,7 +272,7 @@ PangoLayout *layout;
 gchar *valstr;
 int tw, th;
 
-	DB( g_print("\n[column] draw scale\n") );
+	DBG( g_print("\n[column] draw scale\n") );
 
 	first = gtk_adjustment_get_value(GTK_ADJUSTMENT(chart->adjustment));
 
@@ -261,10 +286,13 @@ int tw, th;
 	cairo_set_line_width(cr, 1.0);
 
 	// Y-scale element (horiz lines + labels (amounts))
+	DBG( g_print("\n -- scale-y: [%d - %d]\n", 0, drawctx->div) );
+
 	curxval = drawctx->max;
 	cairo_set_dash(cr, 0, 0, 0);
 	for(i=0 ; i <= drawctx->div ; i++)
 	{
+
 		y = 0.5 + floor (drawctx->graph.y + ((i * drawctx->unit) / drawctx->range) * drawctx->graph.height);
 		//DB( g_print(" + i=%d :: y=%f (%f / %f) * %f\n", i, y, i*chart->unit, chart->range, chart->graph.height) );
 
@@ -278,7 +306,11 @@ int tw, th;
 		cairo_stroke (cr);
 
 		//y-axis label
-		valstr = chart_print_int(chart, (gint)curxval);
+		if( chart->type != CHART_TYPE_STACK100 )
+			valstr = chart_print_int(chart, (gint)curxval);
+		else
+			valstr = chart_print_scalerate(chart, curxval * 100 / drawctx->range );
+		
 		pango_layout_set_text (layout, valstr, -1);
 		pango_layout_get_size (layout, &tw, &th);
 
@@ -302,9 +334,10 @@ int tw, th;
 		x = drawctx->graph.x + (drawctx->blkw/2);
 		y = drawctx->t + drawctx->h - drawctx->font_h;
 
+		DBG( g_print("\n -- scale-x: [%d - %d] visi %d\n", first, first+drawctx->visible, drawctx->visible) );
+
 		for(i=first ; i<(first+drawctx->visible) ; i++)
 		{
-		ChartItem *item = &g_array_index(chart->items, ChartItem, i);
 
 			/*if( chart->dual == TRUE )
 			{
@@ -317,15 +350,24 @@ int tw, th;
 
 			if( chart->show_xval == TRUE )
 			{
+			ChartItem *item = &g_array_index(chart->items, ChartItem, i);
+
 				//TODO: we miss a vertical line here
 
-
 				valstr = item->label;
+
+				if( chart->type == CHART_TYPE_STACK || chart->type == CHART_TYPE_STACK100 )
+					valstr = chart->collabel[i];	
+
+				DBG( g_print(" x: %2d '%s'", i, valstr) );
+
 				pango_layout_set_text (layout, valstr, -1);
 				pango_layout_get_size (layout, &tw, &th);
 				tx = x - ((tw / PANGO_SCALE)/2);
 				if( tx >= lstr )
 				{
+					DBG( g_print(" drawed") );
+
 					if(!drawctx->isprint)
 						cairo_user_set_rgbacol(cr, &global_colors[THTEXT], 0.78);
 					else
@@ -334,7 +376,15 @@ int tw, th;
 					cairo_move_to(cr, tx, y);
 					pango_cairo_show_layout (cr, layout);
 					lstr = x + ((tw / PANGO_SCALE)/2) + CHART_SPACING;
+
+					// draw a marker
+					cairo_move_to(cr, x, drawctx->graph.y + drawctx->graph.height+3);
+					cairo_line_to(cr, x, drawctx->graph.y + drawctx->graph.height);
+					cairo_stroke(cr);
+
 				}
+
+				DBG( g_print("\n") );
 			}
 
 			x += drawctx->blkw;
@@ -355,7 +405,7 @@ int tw, th;
 			y  = 0.5 + drawctx->oy - (ABS(chart->average)/drawctx->range) * drawctx->graph.height;
 		}
 
-		DB( g_print(" draw average: x%d, y%f, w%d\n", drawctx->l, y, drawctx->w) );
+		DBG( g_print(" -- average: x%d, y%f, w%d\n", drawctx->l, y, drawctx->w) );
 
 		if(!drawctx->isprint)
 			cairo_user_set_rgbacol(cr, &global_colors[THTEXT], 1.0);
@@ -369,13 +419,16 @@ int tw, th;
 	}
 
 	/* overdrawn */
-	DB( g_print(" min=%.2f range=%.2f\n", drawctx->min, drawctx->range) );
 
 	if( chart->show_over )
 	{
 		//if(chart->minimum != 0 && chart->minimum >= chart->min)
 		if(chart->minimum >= drawctx->min)
 		{
+
+			DBG( g_print(" -- minimum: min=%.2f range=%.2f\n", drawctx->min, drawctx->range) );
+
+
 			if( chart->minimum < 0 )
 			{
 				y  = 0.5 + drawctx->oy + (ABS(chart->minimum)/drawctx->range) * drawctx->graph.height;
@@ -389,7 +442,7 @@ int tw, th;
 
 			cairo_set_source_rgba(cr, COLTOCAIRO(255), COLTOCAIRO(0), COLTOCAIRO(0), AREA_ALPHA / 2);
 
-			DB( g_print(" draw over: x%d, y%f, w%d, h%f\n", drawctx->l, y, drawctx->w, y2) );
+			DBG( g_print(" draw over: x%d, y%f, w%d, h%f\n", drawctx->l, y, drawctx->w, y2) );
 
 			cairo_rectangle(cr, drawctx->graph.x, y, drawctx->graph.width, y2 );
 			cairo_fill(cr);
@@ -435,7 +488,7 @@ static void linechart_draw_lines(cairo_t *cr, GtkChart *chart, HbtkDrawContext *
 double x, y, x2, y2, firstx, lastx, linew;
 gint first, i;
 
-	DB( g_print("\n[line] draw lines\n") );
+	DBG( g_print("\n[line] draw lines\n") );
 
 	x = drawctx->graph.x;
 	y = drawctx->oy;
@@ -556,12 +609,12 @@ static void colchart_draw_bars(cairo_t *cr, GtkChart *chart, HbtkDrawContext *dr
 double x, x2, y2, h;
 gint i, first;
 
-	DB( g_print("\n[column] draw bars\n") );
+	DBG( g_print("\n[column] draw bars\n") );
 
 	x = drawctx->graph.x;
 	first = (gint)gtk_adjustment_get_value(GTK_ADJUSTMENT(chart->adjustment));
 
-	DB( g_print(" x=%.2f first=%d, blkw=%.2f, barw=%.2f\n", x, first, drawctx->blkw, drawctx->barw ) );
+	DBG( g_print(" x=%.2f first=%d, blkw=%.2f, barw=%.2f\n", x, first, drawctx->blkw, drawctx->barw ) );
 
 	#if DBGDRAW_ITEM == 1
 	x2 = x + 0.5;
@@ -612,7 +665,7 @@ gint i, first;
 					cairo_user_set_rgbcol_over(cr, &chart->color_scheme.colors[color], i == chart->hover);
 				}
 			}
-			//DB( g_print(" + i=%d :: y2=%f h=%f (%f / %f) * %f\n", i, y2, h, chart->datas1[i], chart->range, chart->graph.height ) );
+			//DBG( g_print(" + i=%d :: y2=%f h=%f (%f / %f) * %f\n", i, y2, h, chart->datas1[i], chart->range, chart->graph.height ) );
 
 			cairo_rectangle(cr, x2+2, y2, barw, h);
 			cairo_fill(cr);
@@ -695,7 +748,7 @@ static void colchart_scrollbar_setvalues(GtkChart *chart)
 {
 HbtkDrawContext *drawctx = &chart->context;
 GtkAdjustment *adj = chart->adjustment;
-gint first;
+gint first, nb_items;
 
 	g_return_if_fail (GTK_IS_ADJUSTMENT (adj));
 
@@ -703,23 +756,32 @@ gint first;
 
 	first = gtk_adjustment_get_value(GTK_ADJUSTMENT(adj));
 
-	DB( g_print(" entries=%d, visible=%d\n", chart->nb_items, drawctx->visible) );
-	DB( g_print(" first=%d, upper=%d, pagesize=%d\n", first, chart->nb_items, drawctx->visible) );
+	nb_items = chart->nb_items;
+	if( chart->type == CHART_TYPE_STACK || chart->type == CHART_TYPE_STACK100)
+		nb_items = chart->nb_cols - 1;
 
-	gtk_adjustment_set_upper(adj, (gdouble)chart->nb_items);
+	DB( g_print(" entries=%d, visible=%d\n", nb_items, drawctx->visible) );
+	DB( g_print(" first=%d, upper=%d, pagesize=%d\n", first, nb_items, drawctx->visible) );
+
+	g_object_freeze_notify(G_OBJECT(adj));
+
+	gtk_adjustment_set_upper(adj, (gdouble)nb_items);
 	gtk_adjustment_set_page_size(adj, (gdouble)drawctx->visible);
 	gtk_adjustment_set_page_increment(adj, (gdouble)drawctx->visible);
 
-	if(first+drawctx->visible > chart->nb_items)
+	if(first+drawctx->visible > nb_items)
 	{
-		gtk_adjustment_set_value(adj, (gdouble)chart->nb_items - drawctx->visible);
+		DB( g_print(" set value to %d\n", nb_items - drawctx->visible) );
+		gtk_adjustment_set_value(adj, (gdouble)nb_items - drawctx->visible);
 	}
 
 	#if( (GTK_MAJOR_VERSION == 3) && (GTK_MINOR_VERSION < 18) )
 	gtk_adjustment_changed (adj);
 	#endif
 
-	if( drawctx->visible < chart->nb_items )
+	g_object_thaw_notify(G_OBJECT(adj));
+
+	if( drawctx->visible < nb_items )
 		gtk_widget_hide(GTK_WIDGET(chart->scrollbar));
 	else
 		gtk_widget_show(GTK_WIDGET(chart->scrollbar));
@@ -727,6 +789,313 @@ gint first;
 }
 
 
+/* = = = = = = = = = = = = = = = = */
+/* stack section */
+
+
+// used for stack chart
+void chart_data_series(GtkChart *chart, GtkTreeView *treeview, gint nbrows, gint nbcols)
+{
+GtkTreeModel *model;
+GtkTreeIter iter;
+gboolean valid;
+gdouble tmpmin, tmpmax;
+gint rowid, colid;
+
+	DB( g_print("\n[chart] data series (col graph)\n") );
+
+	g_return_if_fail(GTK_IS_CHART(chart));
+	g_return_if_fail(GTK_IS_TREE_VIEW(treeview));
+
+	chart_clear(chart);
+
+	model  = gtk_tree_view_get_model (treeview);
+
+	DB( g_print(" nbrows=%d nbcols=%d struct=%ld\n", nbrows, nbcols, sizeof(ChartItem)) );
+
+	if( nbrows <=0 || nbcols <= 0 )
+		goto end;
+
+	DB( g_print(" nbrows=%d nbcols=%d\n", nbrows, nbcols) );
+
+	chart->model = model;
+	chart->nb_items = nbrows;
+
+	//TODO temp test - allocate data for sum
+	chart->colsum   = g_malloc0(sizeof(gdouble)*nbcols);
+	chart->collabel = g_malloc0(sizeof(gpointer)*nbcols);
+	chart->nb_cols = nbcols;
+
+	chart->items = g_array_sized_new(FALSE, FALSE, sizeof(ChartItem), chart->nb_items);
+
+	valid = gtk_tree_model_get_iter_first (GTK_TREE_MODEL(model), &iter);
+	rowid = 0;
+	while (valid && rowid < nbrows)
+	{
+	ChartItem item;
+	gchar *label;
+
+		gtk_tree_model_get (GTK_TREE_MODEL(model), &iter,
+			LST_REPDIST2_LABEL, &label,
+			-1);
+
+		//column total
+		//TODO: this is useless, as last row already has the column sum !
+		for(colid=0;colid<nbcols;colid++)
+		{
+		DataRow *dr;
+		gdouble value;
+		
+			gtk_tree_model_get (GTK_TREE_MODEL(model), &iter,
+				//LST_STORE_TRENDROW=6
+				LST_REPDIST2_ROW, &dr,
+				-1);
+
+			value = da_datarow_get_cell_sum (dr, colid);
+			chart->colsum[colid] += ABS(value);
+
+			DB( g_print(" col %3d row %3d val=%.2f\n", colid, rowid, value) );
+		}
+
+		memset(&item, 0, sizeof(item));
+		item.label = label;
+		g_array_append_vals(chart->items, &item, 1);
+
+		valid = gtk_tree_model_iter_next (model, &iter);
+		rowid++;
+	}
+
+	//debug colsum
+	//get minmax
+	tmpmin = 0.0;
+	tmpmax = 0.0;
+
+	DB( g_print(" colsum: ") );
+	for(colid=0;colid<=nbcols;colid++)
+	{
+		tmpmax = MAX(tmpmax, ABS(chart->colsum[colid]));
+		DB( g_print("%.2f|", chart->colsum[colid]) );
+	}
+	DB( g_print("\n") );
+
+
+
+	DB( g_print(" collabel: ") );
+	for(colid=0;colid<nbcols;colid++)
+	{
+	GtkTreeViewColumn *column;
+
+		if( (column = gtk_tree_view_get_column (treeview, colid+1) ))
+		{
+			chart->collabel[colid] = (gchar *)gtk_tree_view_column_get_title(column);
+		}
+
+		DB( g_print("%s|", chart->collabel[colid]) );
+	}
+	DB( g_print("\n") );
+
+
+	// ensure rawmin rawmax not equal
+	if(tmpmin == tmpmax)
+	{
+		tmpmin = 0;
+		tmpmax = 100;
+	}
+
+	DB( g_print(" rawmin=%.2f rawmax=%.2f\n", tmpmin, tmpmax) );
+
+	chart->rawmin = tmpmin;
+	chart->rawmax = tmpmax;
+
+	DB( g_print("[chart] end data series (col graph)\n") );
+end:
+	gtk_chart_queue_redraw(chart);
+}
+
+
+
+static void colchart_draw_stacks(cairo_t *cr, GtkChart *chart, HbtkDrawContext *drawctx)
+{
+double x, x2, y2, h, rate, srate;
+gint i, r, first;
+GtkTreeModel *model = chart->model;
+GtkTreeIter iter;
+gboolean valid;
+
+	DBG( g_print("\n[column] draw stacks\n") );
+
+	x = drawctx->graph.x;
+	first = (gint)gtk_adjustment_get_value(GTK_ADJUSTMENT(chart->adjustment));
+	rate = 0;
+
+	cairo_set_line_width(cr, 1.0);
+
+	DBG( g_print(" x=%.2f first=%d, blkw=%.2f, barw=%.2f\n", x, first, drawctx->blkw, drawctx->barw ) );
+	DBG( g_print(" mono=%d\n", chart->show_mono ) );
+
+	x2 = 0.5 + floor(x + (drawctx->blkw - drawctx->barw)/2);
+
+	DBG( g_print(" x2=%.0f, height=%.0f\n", x2, drawctx->graph.height) );
+
+	//foreach cols
+	for(i=first; i<(first+drawctx->visible) ;i++)
+	//for(i=0; i<chart->nb_items ;i++)
+	{
+//		ChartItem *item = &g_array_index(chart->items, ChartItem, i);
+
+
+		y2 = 0.5 + floor(drawctx->oy);
+
+		DBG( g_print(" draw blk %d\n", i) );
+
+		//Each rows
+		valid = gtk_tree_model_get_iter_first (GTK_TREE_MODEL(model), &iter);
+		r = 0;
+		srate = 0;
+		while (valid)
+		{
+		DataRow *dr;
+		gdouble value;
+		gint id, color;
+		gboolean hover;
+
+			gtk_tree_model_get (GTK_TREE_MODEL(model), &iter,
+				LST_REPDIST2_POS, &id,
+				LST_REPDIST2_ROW, &dr,
+				-1);
+
+			if( id != LST_REPDIST_POS_TOTAL )
+			{
+				value = da_datarow_get_cell_sum (dr, i);
+
+				hover = (i == chart->colhover) && (r == chart->hover) ? TRUE : FALSE;
+
+				color = r % chart->color_scheme.nb_cols;
+				cairo_user_set_rgbcol_over(cr, &chart->color_scheme.colors[color], hover);
+
+				//for stacked
+
+				if(chart->type == CHART_TYPE_STACK)
+					rate = ABS(value/drawctx->range);
+				else if(chart->type == CHART_TYPE_STACK100)
+					//for stacked100
+					rate = ABS(value/chart->colsum[i]);
+
+				//h = 0.5 + floor(rate * drawctx->graph.height);
+				h = rate * drawctx->graph.height;
+
+				//debug sum of rate 
+				srate += h;
+
+				DBG( g_print("  row %2d value=%7.2f x2=%7.2f, y2=%7.2f rate=%f height=%7.2f sheight=%f\n", r, value, x2+2, y2, 100*rate, h, srate) );
+
+				cairo_rectangle(cr, x2+2, y2-h, drawctx->barw, h);
+				cairo_fill(cr);
+
+				y2 = y2 - h;
+			}
+
+			valid = gtk_tree_model_iter_next (model, &iter);
+			r++;
+		}
+
+		x2 += drawctx->blkw;
+
+	}
+
+}
+
+
+
+
+/*
+** get the bar under the mouse pointer
+*/
+static gint colchart_stack_get_hover(GtkWidget *widget, gint x, gint y, gpointer user_data)
+{
+GtkChart *chart = GTK_CHART(user_data);
+HbtkDrawContext *drawctx = &chart->context;
+gint retval;
+gint index, first, px, py, r;
+double y2, h, rate;
+GtkTreeModel *model = chart->model;
+GtkTreeIter iter;
+gboolean valid;
+
+	retval = -1;
+
+	if( x <= (drawctx->l+drawctx->w) && x >= drawctx->graph.x && y >= drawctx->graph.y && y <= (drawctx->t+drawctx->h) )
+	{
+		px = (x - drawctx->graph.x);
+		py = (drawctx->oy - y);
+		first = gtk_adjustment_get_value(GTK_ADJUSTMENT(chart->adjustment));
+		index = first + (px / drawctx->blkw);
+		rate = 0;
+
+		DBD( g_print(" x=%d y=%d px=%d py=%d oy=%f\n", x, y, px, py, drawctx->oy) );
+
+		//we are hover column 'index'
+		if(index < chart->nb_cols)
+		{
+			y2 = 0;
+
+			chart->colhover = index;
+
+			//Each rows
+			valid = gtk_tree_model_get_iter_first (GTK_TREE_MODEL(model), &iter);
+			r = 0;
+			while (valid)
+			{
+			DataRow *dr;
+			gdouble value;
+			gint id;
+
+				gtk_tree_model_get (GTK_TREE_MODEL(model), &iter,
+					LST_REPDIST2_POS, &id,
+					LST_REPDIST2_ROW, &dr,
+					-1);
+
+				if( id != LST_REPDIST_POS_TOTAL )
+				{
+					value = da_datarow_get_cell_sum (dr, index);
+
+					if(chart->type == CHART_TYPE_STACK)
+						rate = ABS(value/drawctx->range);
+					else if(chart->type == CHART_TYPE_STACK100)
+					//for stacked100
+						rate = ABS(value/chart->colsum[index]);
+
+
+					//h = 0.5 + floor(rate * drawctx->graph.height);
+					h = rate * drawctx->graph.height;
+
+					DBD( g_print("  col=%02d row=%2d value=%.0f y2=%.0f rate=%f height=%.0f\n", index, r, value, y2, rate, h) );
+
+					if( py < y2+h )
+					{
+						retval = r;
+						break;
+					}
+
+					y2 = y2 + h;
+				}
+
+				valid = gtk_tree_model_iter_next (model, &iter);
+				r++;
+			}
+
+		}
+
+	}
+
+	DBD( g_print("  stack active=%d\n", retval) );
+
+	return(retval);
+}
+
+
+
+
 /* = = = = = = = = = = = = = = = = */
 /* pie section */
 
@@ -736,7 +1105,7 @@ static void piechart_draw_slices(cairo_t *cr, GtkChart *chart, HbtkDrawContext *
 	if(chart->nb_items <= 0 || chart->total == 0.0)
 		return;
 
-	DB( g_print("\n[pie] draw slices\n") );
+	DBG( g_print("\n[pie] draw slices\n") );
 
 
 		//cairo drawing
@@ -754,8 +1123,8 @@ static void piechart_draw_slices(cairo_t *cr, GtkChart *chart, HbtkDrawContext *
 		double sum = 0.0;
 		gint color;
 
-		DB( g_print("rayon=%d\n", drawctx->rayon) );
-		DB( g_print("total=%.f\n", chart->total) );
+		DBG( g_print("rayon=%d\n", drawctx->rayon) );
+		DBG( g_print("total=%.f\n", chart->total) );
 
 		for(i=0; i< chart->nb_items ;i++)
 		{
@@ -769,7 +1138,7 @@ static void piechart_draw_slices(cairo_t *cr, GtkChart *chart, HbtkDrawContext *
 			dx = cx;
 			dy = cy;
 
-			DB( g_print("- s%2d: %.2f%% a1=%.2f a2=%.2f | %s %.f\n", i, sum / chart->total, a1, a2, item->label, item->serie1) );
+			DBG( g_print("- s%2d: %.2f%% a1=%.2f a2=%.2f | %s %.f\n", i, sum / chart->total, a1, a2, item->label, item->serie1) );
 
 
 			cairo_move_to(cr, dx, dy);
@@ -823,7 +1192,7 @@ gint retval, px, py;
 gint index;
 double radius, h;
 
-	DB( g_print("\n[pie] get hover\n") );
+	DBD( g_print("\n[pie] get hover\n") );
 
 	retval = -1;
 
@@ -856,8 +1225,8 @@ double radius, h;
 			}
 		}
 
-		//DB( g_print(" inside: x=%d, y=%d\n", x, y) );
-		//DB( g_print(" inside: b=%f angle=%f, slice is %d\n", b, angle, index) );
+		//DBD( g_print(" inside: x=%d, y=%d\n", x, y) );
+		//DBD( g_print(" inside: b=%f angle=%f, slice is %d\n", b, angle, index) );
 	}
 	return(retval);
 }
@@ -904,6 +1273,16 @@ static gchar *chart_print_int(GtkChart *chart, gint value)
 }
 
 
+/*
+** print a scale rate number
+*/
+static gchar *chart_print_scalerate(GtkChart *chart, gdouble value)
+{
+	g_snprintf (chart->buffer1, CHART_BUFFER_LENGTH-1, "%.0f%%", value);
+	return chart->buffer1;
+}
+
+
 /*
 ** print a rate number
 */
@@ -968,9 +1347,19 @@ gint i;
 	chart->rawmin = 0;
 	chart->rawmax = 0;
 
+
+	//TODO: temp test
+	g_free(chart->colsum);
+	chart->colsum = NULL;
+	g_free(chart->collabel);
+	chart->collabel = NULL;
+
 	chart->hover = -1;
 	chart->lasthover = -1;
 
+	chart->colhover = -1;
+	chart->lastcolhover = -1;
+
 }
 
 
@@ -993,7 +1382,7 @@ GtkTreeIter iter;
 
 	chart->items = g_array_sized_new(FALSE, FALSE, sizeof(ChartItem), chart->nb_items);
 
-	DB( g_print(" nb=%d, struct=%d\n", chart->nb_items, sizeof(ChartItem)) );
+	DB( g_print(" nb=%d, struct=%d\n", chart->nb_items, (gint)sizeof(ChartItem)) );
 
 	chart->dual = (column1 == column2) ? FALSE : TRUE;
 
@@ -1033,7 +1422,7 @@ GtkTreeIter iter;
 			value2 = ABS(value2);
 		}
 
-		DB( g_print("%d: '%s' %.2f %2f\n", i, label, value1, value2) );
+		DB( g_print("%d: '%s' %.2f %2f\n", rowid, label, value1, value2) );
 
 		/* data1 value storage & min, max compute */
 		chart->rawmin = MIN(chart->rawmin, value1);
@@ -1161,7 +1550,7 @@ gint i;
 	{
 	ChartItem *item = &g_array_index(chart->items, ChartItem, i);
 
-		DBC( g_print(" legend width for %d '%s'\n", i, item->label) );
+		//DBC( g_print(" legend width for %d '%s'\n", i, item->label) );
 
 		// label width
 		pango_layout_set_text (layout, item->label, -1);
@@ -1178,6 +1567,8 @@ gint i;
 	{
 		case CHART_TYPE_LINE:
 		case CHART_TYPE_COL:
+		case CHART_TYPE_STACK:
+		case CHART_TYPE_STACK100:
 			drawctx->graph.x = drawctx->l + drawctx->scale_w + 2;
 			drawctx->graph.width  = drawctx->w - drawctx->scale_w - 2;
 			break;
@@ -1253,6 +1644,8 @@ gint i;
 	{
 		case CHART_TYPE_LINE:
 		case CHART_TYPE_COL:
+		case CHART_TYPE_STACK:
+		case CHART_TYPE_STACK100:
 			colchart_calculation(chart, drawctx);
 			break;
 		case CHART_TYPE_PIE:
@@ -1309,6 +1702,8 @@ GtkAllocation allocation;
 	{
 		case CHART_TYPE_LINE:
 		case CHART_TYPE_COL:
+		case CHART_TYPE_STACK:
+		case CHART_TYPE_STACK100:
 			gtk_adjustment_set_value(chart->adjustment, 0);
 			colchart_scrollbar_setvalues(chart);
 			gtk_widget_show(chart->scrollbar);
@@ -1388,7 +1783,7 @@ int tw, th;
 	gint radius;
 	gint color;
 
-		DB( g_print("\n[chart] draw legend\n") );
+		DBG( g_print("\n[chart] draw legend\n") );
 
 		layout = pango_cairo_create_layout (cr);
 		chart_set_font_size(chart, layout, CHART_FONT_SIZE_SMALL);
@@ -1414,7 +1809,7 @@ int tw, th;
 
 			if(item)
 			{
-				DB( g_print(" draw %2d of (%d) '%s' y=%d\n", i, chart->nb_items, item->label, y) );
+				DBG( g_print(" draw %2d of (%d) '%s' y=%d\n", i, chart->nb_items, item->label, y) );
 
 				#if DBGDRAW_TEXT == 1
 					double dashlength;
@@ -1433,7 +1828,7 @@ int tw, th;
 				{
 					if( (y + floor(2 * radius * CHART_LINE_SPACING)) > (drawctx->t + drawctx->h) )
 					{
-						DB( g_print(" print ...\n\n") );
+						DBG( g_print(" print ...\n\n") );
 						pango_layout_set_text (layout, "...", -1);
 						cairo_move_to(cr, x + radius + CHART_SPACING, y);
 						pango_cairo_show_layout (cr, layout);
@@ -1520,7 +1915,7 @@ GtkAllocation allocation;
 cairo_t *cr;
 
 
-	DB( g_print("\n[gtkchart] drawarea full redraw\n") );
+	DBG( g_print("\n[gtkchart] drawarea full redraw\n") );
 
 	cr = cairo_create (chart->surface);
 
@@ -1562,6 +1957,8 @@ cairo_scaled_font_t *sf;
 	{
 		case CHART_TYPE_COL:
 		case CHART_TYPE_LINE:
+		case CHART_TYPE_STACK:
+		case CHART_TYPE_STACK100:
 			{
 			cairo_t *crs;
 
@@ -1638,20 +2035,20 @@ GdkRGBA color;
 		chart->pfd = NULL;
 	}
 	chart->pfd = pango_font_description_copy(desc);
-	//chart->pfd_size = pango_font_description_get_size (desc) / PANGO_SCALE;
-	//chart->barw = (6 + chart->pfd_size) * PHI;
 
-	//leak: we should free desc here ?
-	//or no need to copy above ?
-	//pango_font_description_free(desc);
 
-	DB( g_print("family: %s\n", pango_font_description_get_family(chart->pfd) ) );
-	//DB( g_print("size  : %d (%d)\n", chart->pfd_size, chart->pfd_size/PANGO_SCALE ) );
-	DB( g_print("isabs : %d\n", pango_font_description_get_size_is_absolute (chart->pfd) ) );
+	//#1919063 overwrite pango size with device unit taken from css
+	GValue value = G_VALUE_INIT;
+	gtk_style_context_get_property(context, "font-size", gtk_style_context_get_state(context), &value);
+
+	DB( g_print("font-size is: %f\n", g_value_get_double(&value) ) );
+
+	pango_font_description_set_absolute_size (chart->pfd, (gint)g_value_get_double(&value)*PANGO_SCALE);
+
+	g_value_unset(&value);
 }
 
 
-
 static gboolean
 drawarea_configure_event_callback (GtkWidget         *widget,
                           GdkEventConfigure *event,
@@ -1757,6 +2154,10 @@ GtkChart *chart = GTK_CHART(user_data);
 		case CHART_TYPE_PIE:
 			piechart_draw_slices(cr, chart, &chart->context);
 			break;
+		case CHART_TYPE_STACK:
+		case CHART_TYPE_STACK100:
+			colchart_draw_stacks(cr, chart, &chart->context);
+			break;
 	}
 
 	// event handled
@@ -1767,15 +2168,16 @@ GtkChart *chart = GTK_CHART(user_data);
 static gboolean drawarea_querytooltip_callback(GtkWidget *widget, gint x, gint y, gboolean keyboard_mode, GtkTooltip *tooltip, gpointer user_data)
 {
 GtkChart *chart = GTK_CHART(user_data);
-gchar *strval, *strval2, *buffer;
+gchar *strval, *strval2;
+gchar *buffer = NULL;
 gboolean retval = FALSE;
 
 	if(chart->surface == NULL)
 		return FALSE;
 
-	DBD( g_print("\n[gtkchart] drawarea querytooltip\n") );
+	DBT( g_print("\n[gtkchart] drawarea querytooltip\n") );
 
-	DBD( g_print(" x=%d, y=%d kbm=%d\n", x, y, keyboard_mode) );
+	DBT( g_print(" x=%d, y=%d kbm=%d\n", x, y, keyboard_mode) );
 	if(chart->lasthover != chart->hover)
 	{
 		goto end;
@@ -1785,20 +2187,51 @@ gboolean retval = FALSE;
 	{
 	ChartItem *item = &g_array_index(chart->items, ChartItem, chart->hover);
 
-		strval = chart_print_double(chart, chart->buffer1, item->serie1);
-		if( !chart->dual )
+		if( chart->type != CHART_TYPE_STACK && chart->type != CHART_TYPE_STACK100 )
 		{
-			//#1420495 don't use g_markup_printf_escaped
-			if( chart->type == CHART_TYPE_PIE )
-				buffer = g_strdup_printf("%s\n%s\n%.2f%%", item->label, strval, item->rate);
-			else
-				buffer = g_strdup_printf("%s\n%s", item->label, strval);
+			strval = chart_print_double(chart, chart->buffer1, item->serie1);
+			if( !chart->dual )
+			{
+				//#1420495 don't use g_markup_printf_escaped
+				if( chart->type == CHART_TYPE_PIE )
+					buffer = g_strdup_printf("%s\n%s\n%.2f%%", item->label, strval, item->rate);
+				else
+					buffer = g_strdup_printf("%s\n%s", item->label, strval);
 
+			}
+			else
+			{
+				strval2 = chart_print_double(chart, chart->buffer2, item->serie2);
+				buffer = g_strdup_printf("%s\n+%s\n%s", item->label, strval2, strval);
+			}
 		}
 		else
 		{
-			strval2 = chart_print_double(chart, chart->buffer2, item->serie2);
-			buffer = g_strdup_printf("%s\n+%s\n%s", item->label, strval2, strval);
+		gint colid = chart->colhover;	
+		GtkTreeIter iter;
+		DataRow *dr;
+		gdouble value, rate;
+
+			if( colid > -1 )
+			{
+				gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(chart->model), &iter, NULL, chart->hover);
+				
+				gtk_tree_model_get (GTK_TREE_MODEL(chart->model), &iter,
+					//LST_STORE_TRENDROW=6
+					LST_REPDIST2_ROW, &dr,
+					-1);
+
+				value = da_datarow_get_cell_sum (dr, colid);
+				strval = chart_print_double(chart, chart->buffer1, value);
+				
+				if( chart->type == CHART_TYPE_STACK )
+					buffer = g_strdup_printf("%s\n%s\n%s", chart->collabel[colid], item->label, strval);
+				else
+				{
+					rate = (value * 100) / chart->colsum[colid];
+					buffer = g_strdup_printf("%s\n%s\n%s\n%.2f%%", chart->collabel[colid], item->label, strval, rate);
+				}
+			}
 		}
 
 		gtk_tooltip_set_text(tooltip, buffer);
@@ -1831,6 +2264,7 @@ gint x, y;
 	//DBD( g_print(" x=%d, y=%d\n", x, y) );
 
 	chart->hover = -1;
+	chart->colhover = -1;
 
 	//todo see this
 	/*if(event->is_hint)
@@ -1842,41 +2276,47 @@ gint x, y;
 		//return FALSE;
 	}*/
 
-	switch(chart->type)
-	{
-		case CHART_TYPE_COL:
-		case CHART_TYPE_LINE:
-			chart->hover = colchart_get_hover(widget, x, y, chart);
-			break;
-		case CHART_TYPE_PIE:
-			chart->hover = piechart_get_hover(widget, x, y, chart);
-			break;
-	}
+		switch(chart->type)
+		{
+			case CHART_TYPE_COL:
+			case CHART_TYPE_LINE:
+				chart->hover = colchart_get_hover(widget, x, y, chart);
+				break;
+			case CHART_TYPE_STACK:
+			case CHART_TYPE_STACK100:
+				chart->hover = colchart_stack_get_hover(widget, x, y, chart);
+				break;
+			case CHART_TYPE_PIE:
+				chart->hover = piechart_get_hover(widget, x, y, chart);
+				break;
+		}
 
 	//test: eval legend
-	if( chart->show_legend && chart->hover == - 1)
+	if( chart->type != CHART_TYPE_STACK && chart->type != CHART_TYPE_STACK100 )
 	{
-		DBD( g_print(" hover legend\n") );
-
-		if( x >= drawctx->legend.x && (x <= (drawctx->legend.x+drawctx->legend.width ))
-		&&  y >= drawctx->legend.y && (y <= (drawctx->legend.y+drawctx->legend.height ))
-		)
+		if( chart->show_legend && chart->hover == - 1)
 		{
-			//use the radius a font height here
-			chart->hover = (y - drawctx->legend.y) / floor(drawctx->legend_font_h * CHART_LINE_SPACING);
-		}
+			DBD( g_print(" hover legend\n") );
 
-		if( chart->hover > chart->nb_items - 1)
-		{
-			chart->hover = -1;
+			if( x >= drawctx->legend.x && (x <= (drawctx->legend.x+drawctx->legend.width ))
+			&&  y >= drawctx->legend.y && (y <= (drawctx->legend.y+drawctx->legend.height ))
+			)
+			{
+				//use the radius a font height here
+				chart->hover = (y - drawctx->legend.y) / floor(drawctx->legend_font_h * CHART_LINE_SPACING);
+			}
+
+			if( chart->hover > chart->nb_items - 1)
+			{
+				chart->hover = -1;
+			}
 		}
 	}
 
-
 	// rollover redraw ?
 	DBD( g_print(" hover: last=%d, curr=%d\n", chart->lasthover, chart->hover) );
 
-	if(chart->lasthover != chart->hover)
+	if( (chart->lasthover != chart->hover) || (chart->lastcolhover != chart->colhover) )
 	{
 	GdkRectangle update_rect;
 	gint first;
@@ -1885,53 +2325,46 @@ gint x, y;
 
 		first = (gint)gtk_adjustment_get_value(GTK_ADJUSTMENT(chart->adjustment));
 
-		// pie : always invalidate all graph area
-		if( chart->type == CHART_TYPE_PIE )
+		switch( chart->type )
 		{
-			update_rect.x = drawctx->graph.x;
-			update_rect.y = drawctx->graph.y;
-			update_rect.width = drawctx->graph.width;
-			update_rect.height = drawctx->graph.height;
+			case CHART_TYPE_PIE:
+			case CHART_TYPE_STACK:
+			case CHART_TYPE_STACK100:
+				//invalidate all graph area
+				update_rect.x = drawctx->graph.x;
+				update_rect.y = drawctx->graph.y;
+				update_rect.width = drawctx->graph.width;
+				update_rect.height = drawctx->graph.height;
 
-			/* Now invalidate the affected region of the drawing area. */
-			gdk_window_invalidate_rect (gtk_widget_get_window (widget),
-		                          &update_rect,
-		                          FALSE);
-		}
+				/* Now invalidate the affected region of the drawing area. */
+				gdk_window_invalidate_rect (gtk_widget_get_window (widget), &update_rect, FALSE);
+				break;
 
-		if(chart->lasthover != -1)
-		{
-			// column/line : invalidate rollover
-			if( chart->type == CHART_TYPE_COL || chart->type == CHART_TYPE_LINE )
-			{
-				update_rect.x = drawctx->graph.x + (chart->lasthover - first) * drawctx->blkw;
+			case CHART_TYPE_COL:
+			case CHART_TYPE_LINE:
+				//invalidate last rollover block
+				if(chart->lasthover != -1)
+				{
+					update_rect.x = drawctx->graph.x + (chart->lasthover - first) * drawctx->blkw;
+					update_rect.y = drawctx->graph.y - 6;
+					update_rect.width = drawctx->blkw;
+					update_rect.height = drawctx->graph.height + 12;
+
+					// Now invalidate the affected region of the drawing area
+					gdk_window_invalidate_rect (gtk_widget_get_window (widget), &update_rect, FALSE);
+				}
+
+				//current item block
+				update_rect.x = drawctx->graph.x + (chart->hover - first) * drawctx->blkw;
 				update_rect.y = drawctx->graph.y - 6;
 				update_rect.width = drawctx->blkw;
 				update_rect.height = drawctx->graph.height + 12;
-			}
 
-			// Now invalidate the affected region of the drawing area
-			gdk_window_invalidate_rect (gtk_widget_get_window (widget),
-		                          &update_rect,
-		                          FALSE);
+				/* Now invalidate the affected region of the drawing area. */
+				gdk_window_invalidate_rect (gtk_widget_get_window (widget), &update_rect, FALSE);
+				break;
+
 		}
-
-		// column/line : invalidate current item
-		if( chart->type == CHART_TYPE_COL || chart->type == CHART_TYPE_LINE )
-		{
-			update_rect.x = drawctx->graph.x + (chart->hover - first) * drawctx->blkw;
-			update_rect.y = drawctx->graph.y - 6;
-			update_rect.width = drawctx->blkw;
-			update_rect.height = drawctx->graph.height + 12;
-
-			/* Now invalidate the affected region of the drawing area. */
-			gdk_window_invalidate_rect (gtk_widget_get_window (widget),
-			                      &update_rect,
-			                      FALSE);
-		}
-
-		//gtk_widget_queue_draw( widget );
-		//retval = FALSE;
 	}
 
 	DBD( g_print(" x=%d, y=%d, time=%d\n", x, y, event->time) );
@@ -1939,6 +2372,8 @@ gint x, y;
 	//if(inlegend != TRUE)
 	//	gtk_tooltip_trigger_tooltip_query(gtk_widget_get_display(chart->drawarea));
 
+	chart->lastcolhover = chart->colhover;
+
 	return retval;
 }
 
@@ -2019,6 +2454,10 @@ gdouble t, b, l, r, w, h;
 		case CHART_TYPE_LINE:
 			linechart_draw_lines(cr, data->chart, drawctx);
 			break;
+		case CHART_TYPE_STACK:
+		case CHART_TYPE_STACK100:
+			colchart_draw_stacks(cr, data->chart, drawctx);
+			break;
 	}
 
 	//restore usrbarw
@@ -2432,6 +2871,10 @@ GtkWidget *widget, *vbox, *frame;
 	chart->items = NULL;
  	chart->title = NULL;
 
+	//TODO temp test
+	chart->colsum = NULL;
+	chart->collabel = NULL;
+
   	chart->pfd = NULL;
 	chart->abs = FALSE;
 	chart->dual = FALSE;
@@ -2442,6 +2885,8 @@ GtkWidget *widget, *vbox, *frame;
 	chart->show_mono = FALSE;
 	chart->hover = -1;
 	chart->lasthover = -1;
+	chart->colhover = -1;
+	chart->lastcolhover = -1;
 
  	chart->minor_rate = 1.0;
 
