@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2021 Maxime DOYEN
+ *  Copyright (C) 1995-2022 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -20,7 +20,7 @@
 
 //#include <time.h>
 #include <stdlib.h>		/* atoi, atof, atol */
-#include <libintl.h>
+#include <libintl.h>	/* gettext */
 
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
@@ -55,8 +55,7 @@ G_DEFINE_TYPE_WITH_CODE(GtkDateEntry, gtk_date_entry, GTK_TYPE_BOX, G_ADD_PRIVAT
 
 
 
-// todo:finish this
-// this is to be able to seizure d or d/m or m/d in the gtkdateentry
+gboolean using_twodigit_years = FALSE;
 
 /* order of these in the current locale */
 static GDateDMY dmy_order[3] = 
@@ -67,98 +66,168 @@ static GDateDMY dmy_order[3] =
 struct _GDateParseTokens {
   gint num_ints;
   gint n[3];
-  guint month;
 };
 
 typedef struct _GDateParseTokens GDateParseTokens;
 
 #define NUM_LEN 10
 
-static void gtk_date_entry_cb_calendar_today_mark(GtkWidget *calendar, GtkDateEntry *dateentry);
+
+/* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
+
 
 static void
 hb_date_fill_parse_tokens (const gchar *str, GDateParseTokens *pt)
 {
-  gchar num[4][NUM_LEN+1];
-  gint i;
-  const guchar *s;
-  
-  //DB( g_print("\n[dateentry] fill parse token\n") );
-  
-  /* We count 4, but store 3; so we can give an error
-   * if there are 4.
-   */
-  num[0][0] = num[1][0] = num[2][0] = num[3][0] = '\0';
-  
-  s = (const guchar *) str;
-  pt->num_ints = 0;
-  while (*s && pt->num_ints < 4) 
-    {
-      
-      i = 0;
-      while (*s && g_ascii_isdigit (*s) && i < NUM_LEN)
-        {
-          num[pt->num_ints][i] = *s;
-          ++s; 
-          ++i;
-        }
-      
-      if (i > 0) 
-        {
-          num[pt->num_ints][i] = '\0';
-          ++(pt->num_ints);
-        }
-      
-      if (*s == '\0') break;
-      
-      ++s;
-    }
-  
-  pt->n[0] = pt->num_ints > 0 ? atoi (num[0]) : 0;
-  pt->n[1] = pt->num_ints > 1 ? atoi (num[1]) : 0;
-  pt->n[2] = pt->num_ints > 2 ? atoi (num[2]) : 0;
+gchar num[4][NUM_LEN+1];
+gint i;
+const guchar *s;
+
+	//DB( g_print("\n[dateentry] fill parse token\n") );
+
+	/* We count 4, but store 3; so we can give an error
+	* if there are 4.
+	*/
+	num[0][0] = num[1][0] = num[2][0] = num[3][0] = '\0';
+
+	s = (const guchar *) str;
+	pt->num_ints = 0;
+	while (*s && pt->num_ints < 4) 
+	{
+		i = 0;
+		while (*s && g_ascii_isdigit (*s) && i < NUM_LEN)
+		{
+			num[pt->num_ints][i] = *s;
+			++s; 
+			++i;
+		}
+
+		if (i > 0) 
+		{
+			num[pt->num_ints][i] = '\0';
+			++(pt->num_ints);
+		}
+
+		if (*s == '\0') break;
+
+		++s;
+	}
+
+	pt->n[0] = pt->num_ints > 0 ? atoi (num[0]) : 0;
+	pt->n[1] = pt->num_ints > 1 ? atoi (num[1]) : 0;
+	pt->n[2] = pt->num_ints > 2 ? atoi (num[2]) : 0;
 
 }
 
 
-static void hb_date_parse_tokens(GDate *date, const gchar *str)
+static void
+hb_date_determine_dmy_order(void)
+{
+GDateParseTokens testpt;
+GDate d;
+gchar buf[127];
+gint i;
+
+	DB( g_print("\n[dateentry] determine dmy order\n") );
+
+	/* had to pick a random day - don't change this, some strftimes
+	* are broken on some days, and this one is good so far. */
+	g_date_set_dmy (&d, 4, 7, 1976);
+
+	g_date_strftime (buf, 127, "%x", &d);
+
+	hb_date_fill_parse_tokens (buf, &testpt);
+
+	using_twodigit_years = FALSE;
+	dmy_order[0] = G_DATE_DAY;
+	dmy_order[1] = G_DATE_MONTH;
+	dmy_order[2] = G_DATE_YEAR;
+
+	i = 0;
+	while (i < testpt.num_ints)
+	{
+		switch (testpt.n[i])
+		{
+		case 7:
+			dmy_order[i] = G_DATE_MONTH;
+			break;
+		case 4:
+			dmy_order[i] = G_DATE_DAY;
+			break;
+		case 76:
+			using_twodigit_years = TRUE; /* FALL THRU */
+		case 1976:
+			dmy_order[i] = G_DATE_YEAR;
+		break;
+		}
+		++i;
+	}
+
+	DB( g_print(" => dmy=%d mdy=%d ymd=%d\n", dmy_order[0]==G_DATE_DAY, dmy_order[0]==G_DATE_MONTH, dmy_order[0]==G_DATE_YEAR) );
+
+}
+
+
+static void 
+hb_date_parse_tokens(GDate *date, const gchar *str)
 {
 GDateParseTokens pt;
+GDate tokendate;
+gboolean tokened = FALSE;
 
 	hb_date_fill_parse_tokens(str, &pt);
-	DB( g_print(" -> parsetoken return %d values: %d %d %d\n", pt.num_ints, pt.n[0], pt.n[1], pt.n[2]) );
+
+	//DB( g_print(" > parsetoken return %d values: %d %d %d\n", pt.num_ints, pt.n[0], pt.n[1], pt.n[2]) );
 
 	// initialize with today's date
-	g_date_set_time_t(date, time(NULL));
+	g_date_set_time_t(&tokendate, time(NULL));
 	
 	switch( pt.num_ints )
 	{
 		case 1:
-			DB( g_print(" -> seizured 1 number\n") );
 			if(g_date_valid_day(pt.n[0]))
-				g_date_set_day(date, pt.n[0]);
+			{
+				DB( g_print("  > set day to %02d\n", pt.n[0]) );
+				g_date_set_day(&tokendate, pt.n[0]);
+				tokened = TRUE;
+			}
 			break;
 		case 2:
-			DB( g_print(" -> seizured 2 numbers\n") );
 			if( dmy_order[0] != G_DATE_YEAR )
 			{
 				if( dmy_order[0] == G_DATE_DAY )
 				{
-					if(g_date_valid_day(pt.n[0]))
-					    g_date_set_day(date, pt.n[0]);
-					if(g_date_valid_month(pt.n[1]))
-						g_date_set_month(date, pt.n[1]);
+					if( g_date_valid_day(pt.n[0]) && g_date_valid_month(pt.n[1]) )
+					{
+						DB( g_print("  > set day/month to %02d %02d\n", pt.n[0], pt.n[1]) );
+					    g_date_set_day(&tokendate, pt.n[0]);
+						g_date_set_month(&tokendate, pt.n[1]);
+						tokened = TRUE;
+					}
 				}
 				else
 				{
-					if(g_date_valid_day(pt.n[1]))
-					    g_date_set_day(date, pt.n[1]);
-					if(g_date_valid_month(pt.n[0]))
-						g_date_set_month(date, pt.n[0]);
+					if( g_date_valid_day(pt.n[1]) && g_date_valid_month(pt.n[0]) )
+					{
+						DB( g_print("  > set day/month to %02d %02d\n", pt.n[1], pt.n[0]) );
+					    g_date_set_day(&tokendate, pt.n[1]);
+						g_date_set_month(&tokendate, pt.n[0]);
+						tokened = TRUE;
+					}
 				}
 			}
 			break;
-	}	
+		default:
+			DB( g_print("  > nothing done\n") );
+			break;
+	}
+
+	if( tokened == TRUE && g_date_valid(&tokendate) )
+	{
+		g_date_set_julian(date, g_date_get_julian(&tokendate));
+	}
+	else
+		g_date_clear(date, 1);
 }
 
 
@@ -166,12 +235,12 @@ static void
 update_text(GtkDateEntry *self)
 {
 GtkDateEntryPrivate *priv = self->priv;
-gchar label[256];
+gchar label[127];
 
 	DB( g_print("\n[dateentry] update text\n") );
 
 	//%x : The preferred date representation for the current locale without the time.
-	g_date_strftime (label, 256 - 1, "%x", priv->date);
+	g_date_strftime (label, 127 - 1, "%x", priv->date);
 	gtk_entry_set_text (GTK_ENTRY (priv->entry), label);
 	DB( g_print(" = %s\n", label) );
 }
@@ -182,6 +251,8 @@ eval_date(GtkDateEntry *self)
 {
 GtkDateEntryPrivate *priv = self->priv;
 
+	DB( g_print("\n[dateentry] eval date\n") );
+
 	DB( g_print(" pre %d %d %d\n", g_date_get_day(priv->date), g_date_get_month(priv->date), g_date_get_year(priv->date)) );
 
 	g_date_clamp(priv->date, &priv->mindate, &priv->maxdate);
@@ -207,28 +278,53 @@ parse_date(GtkDateEntry *self)
 {
 GtkDateEntryPrivate *priv = self->priv;
 const gchar *str;
-	
+
 	DB( g_print("\n[dateentry] parse date\n") );
 
 	str = gtk_entry_get_text (GTK_ENTRY (priv->entry));
 
-	//1) we parse the string according to the locale
-	g_date_set_parse (priv->date, str);
-	DB( g_print(" parsed '%s' %d %d %d\n", str, g_date_get_day(priv->date), g_date_get_month(priv->date), g_date_get_year(priv->date)) );
+	DB( g_print(" inputstr='%s'\n", str) );
 
-	if(!g_date_valid(priv->date) || g_date_get_julian (priv->date) <= HB_MINDATE)
-	{
-		//2) give a try to tokens: day, day/month, month/day
-		hb_date_parse_tokens(priv->date, str);
-		DB( g_print(" tokened %d %d %d\n", g_date_get_day(priv->date), g_date_get_month(priv->date), g_date_get_year(priv->date)) );
-	}
+	//1) give a try to tokens = day, day/month, month/day
+	hb_date_parse_tokens(priv->date, str);
+	DB( g_print(" 2/ hb_tokens :: valid=%d\n", g_date_valid(priv->date)) );
 
-	//3) at last if date still invalid, put today's dateentry_signals
-	// we should consider just warn the user here
 	if(!g_date_valid(priv->date))
 	{
-		g_date_set_time_t(priv->date, time(NULL));
+		//2) we parse the string according to the locale
+		g_date_set_parse (priv->date, str);
+
+		DB( g_print(" 1/ glib parsed :: valid=%d\n", g_date_valid(priv->date)) );
+
+		//#1956185 adjust for 2 digits year, note: IBM is windowing 40, not 60
+		if( g_date_valid(priv->date) == TRUE )
+		{
+			if( g_date_get_year(priv->date) < 1970 )
+			{
+				DB( g_print(" > adjusting year %04d from 2 to 4 digits\n", g_date_get_year(priv->date)) );
+				if( g_date_get_year(priv->date) < 60 )
+					g_date_add_years(priv->date, 2000);
+				else
+					g_date_add_years(priv->date, 1900);
+				DB( g_print(" > year set to %d\n", g_date_get_year(priv->date)) );
+			}
+		}
 	}
+
+	//3) at last put today's date and warn the user
+	if(!g_date_valid(priv->date))
+	{
+		DB( g_print(" 3/ invalid, set today and warn\n") );
+		g_date_set_time_t(priv->date, time(NULL));
+		gtk_style_context_add_class (gtk_widget_get_style_context (GTK_WIDGET(priv->entry)), GTK_STYLE_CLASS_WARNING);
+	}
+	else
+	{
+		gtk_style_context_remove_class (gtk_widget_get_style_context (GTK_WIDGET(priv->entry)), GTK_STYLE_CLASS_WARNING);
+	}
+
+	DB( g_print(" date is d:%02d m:%02d y:%04d\n", g_date_get_day(priv->date), g_date_get_month(priv->date), g_date_get_year(priv->date)) );
+
 	eval_date(self);
 }
 
@@ -637,6 +733,9 @@ GtkDateEntry *dateentry;
 	
 		if(label)
 			gtk_label_set_mnemonic_widget (GTK_LABEL(label), priv->entry);
+
+		hb_date_determine_dmy_order();
+
 	}
 	return GTK_WIDGET(dateentry);
 }
