@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2021 Maxime DOYEN
+ *  Copyright (C) 1995-2022 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -58,16 +58,24 @@ struct _account
 	gboolean	flt_select;		//true if selected into filter
 };
 
-// 0 is free
+
+// data flags
+//gushort is 2 bytes / 16 bits
+//FREE (1<<0) 
 #define AF_CLOSED		(1<<1)
-#define AF_ADDED		(1<<2)
-#define AF_CHANGED		(1<<3)
+
 #define AF_NOSUMMARY	(1<<4)
 #define AF_NOBUDGET		(1<<5)
 #define AF_NOREPORT		(1<<6)
 
+//unsaved tmp flags
+#define AF_ADDED		(1<<9)	//was 1<<2 < 5.5.3
+#define AF_CHANGED		(1<<10)	//was 1<<3 < 5.5.3
+
+//deprecated
 #define AF_OLDBUDGET	(1<<0)
 
+
 enum
 {
 // + https://www.kashoo.com/blog/what-are-the-different-account-types-in-accounting/
@@ -113,13 +121,14 @@ Account		*da_acc_get(guint32 key);
 void da_acc_consistency(Account *item);
 
 GtkWindow *account_window(guint32 key);
+void account_transaction_sort(void);
 gboolean account_is_used(guint32 key);
 gboolean account_exists(gchar *name);
 gboolean account_rename(Account *item, gchar *newname);
 void account_set_currency(Account *item, guint32 kcur);
 void account_compute_balances(void);
-gboolean account_balances_add(Transaction *trn);
-gboolean account_balances_sub(Transaction *trn);
+gboolean account_balances_add(Transaction *txn);
+gboolean account_balances_sub(Transaction *txn);
 
 GList *account_glist_sorted(gint column);
 
