@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2021 Maxime DOYEN
+ *  Copyright (C) 1995-2022 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -681,15 +681,13 @@ Transaction *txn;
 	count = 0;
 
 	maxpostdate = scheduled_date_get_post_max();
-
-	txn = da_transaction_malloc();
 	
 	list = g_list_first(GLOBALS->arc_list);
 	while (list != NULL)
 	{
 	Archive *arc = list->data;
 
-		DB( g_print("\n eval %d for '%s'\n", scheduled_is_postable(arc), arc->memo) );
+		DB( g_print("--------\n eval post of '%s' %.2f\n", arc->memo, arc->amount) );
 
 		if(scheduled_is_postable(arc) == TRUE)
 		{
@@ -703,12 +701,18 @@ Transaction *txn;
 				while(mydate < maxpostdate)
 				{
 					DB( hb_print_date(mydate, arc->memo) );
-					
+					//5.5.3 fixed leak as this was outside the loop
+					txn = da_transaction_malloc();
+
 					da_transaction_init_from_template(txn, arc);
 					txn->date = scheduled_get_postdate(arc, mydate);
 					/* todo: ? fill in cheque number */
 
+					DB( g_print(" -- post --\n") );
 					transaction_add(NULL, txn);
+
+					da_transaction_free (txn);
+
 					GLOBALS->changes_count++;
 					count++;
 
@@ -725,8 +729,6 @@ Transaction *txn;
 nextarchive:
 		list = g_list_next(list);
 	}
-
-	da_transaction_free (txn);
 	
 	return count;
 }
