@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2021 Maxime DOYEN
+ *  Copyright (C) 1995-2022 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -846,6 +846,8 @@ gint count = 0;
 						&& (gentxn2->amount == gentxn1->amount)
 						&& (hb_string_compare(gentxn2->memo, gentxn1->memo) == 0)
 						&& (hb_string_compare(gentxn2->payee, gentxn1->payee) == 0)
+					    //#1954017 add comparison on category
+					    && (hb_string_compare(gentxn2->category, gentxn1->category) == 0)
 					  )
 					{
 						isimpsimilar = TRUE;
