@@ -233,6 +233,7 @@ gint i;
 	PREFS->lst_acc_columns[i++] = COL_DSPACC_FUTURE;
 
 	PREFS->pnl_upc_col_pay_width = -1;
+	PREFS->pnl_upc_col_cat_width = -1;
 	PREFS->pnl_upc_col_mem_width = -1;
 	PREFS->pnl_upc_range = FLT_SCHEDULED_ALLDATE;
 
@@ -801,6 +802,7 @@ GError *error = NULL;
 				}						
 
 				homebank_pref_get_short(keyfile, group, "UpcColPayW", &PREFS->pnl_upc_col_pay_width);
+				homebank_pref_get_short(keyfile, group, "UpcColCatW", &PREFS->pnl_upc_col_cat_width);
 				homebank_pref_get_short(keyfile, group, "UpcColMemW", &PREFS->pnl_upc_col_mem_width);
 				homebank_pref_get_integer(keyfile, group, "UpcRange", &PREFS->pnl_upc_range);
 
@@ -1072,6 +1074,7 @@ GError *error = NULL;
 		g_key_file_set_integer_list(keyfile, group, "AccColumns", PREFS->lst_acc_columns, NUM_LST_COL_DSPACC);
 
 		g_key_file_set_integer(keyfile, group, "UpcColPayW", PREFS->pnl_upc_col_pay_width);
+		g_key_file_set_integer(keyfile, group, "UpcColCatW", PREFS->pnl_upc_col_cat_width);
 		g_key_file_set_integer(keyfile, group, "UpcColMemW", PREFS->pnl_upc_col_mem_width);
 		g_key_file_set_integer(keyfile, group, "UpcRange", PREFS->pnl_upc_range);
 
