@@ -26,7 +26,7 @@
 
 
 #include <errno.h>
-#include <math.h>
+#include <math.h>		/* floor */
 #include <libintl.h>	/* gettext */
 #include <locale.h>
 #include <stdlib.h>		/* atoi, atof, atol */
@@ -75,13 +75,13 @@
 
 #define HOMEBANK_MAJOR	5
 #define HOMEBANK_MINOR	5
-#define HOMEBANK_MICRO	4
+#define HOMEBANK_MICRO	5
 
-#define HB_VERSION		"5.5.4"
+#define HB_VERSION		"5.5.5"
 #define HB_VERSION_NUM	(HOMEBANK_MAJOR*10000) + (HOMEBANK_MINOR*100) + HOMEBANK_MICRO
 
 #define FILE_VERSION		1.4
-#define PREF_VERSION		554
+#define PREF_VERSION		555
 
 #if HB_UNSTABLE == FALSE
 	#define	PROGNAME		"HomeBank"
