@@ -205,6 +205,7 @@ guint j;
 
 		DB( g_print(" g '%s'\n", g->name) );
 
+		g->showtotal = TRUE;
 		g->bal_recon = 0;
 		g->bal_clear = 0;
 		g->bal_today = 0;
@@ -220,11 +221,18 @@ guint j;
 				g->bal_today += hb_amount_base(acc->bal_today, acc->kcur);
 				g->bal_future += hb_amount_base(acc->bal_future, acc->kcur);
 
+				//#1950234 show subtotal when single with foreign currency
+				if( (g->acclist->len == 1) && (acc->kcur == GLOBALS->kcur) )
+				{
+					g->showtotal = FALSE;
+				}
+
 			}
 		}
+		
+		DB( g_print("  + total :: %.2f %.2f %.2f %.2f - showsub:%d\n", g->bal_recon, g->bal_clear, g->bal_today, g->bal_future, g->showtotal) );
 
-		DB( g_print("  + total :: %.2f %.2f %.2f %.2f\n", g->bal_recon, g->bal_clear, g->bal_today, g->bal_future) );
-
+		//sum for grand total		
 		gt->bal_recon += g->bal_recon;
 		gt->bal_clear += g->bal_clear;
 		gt->bal_today += g->bal_today;
@@ -259,7 +267,9 @@ gpointer key, value;
 	h_group = ui_hub_account_groups_get(GTK_TREE_VIEW(data->LV_acc), PREFS->pnl_acc_show_by, data->showall);
 	data->h_accgrp = h_group;
 	data->totaccgrp = da_accgrp_malloc();
-		               
+
+	ui_hub_account_groups_compute(data->h_accgrp, data->totaccgrp);
+	
 	DB( g_print("\n\n populate listview, %d group(s)\n", g_hash_table_size(h_group)) );
 
 	nbtype = 0;
@@ -313,8 +323,10 @@ gpointer key, value;
 					  -1);
 			}
 
-			// insert the total line
-			if(group->acclist->len > 1)
+			// insert group total line
+			//if(group->acclist->len > 1)
+			//#1950234 show subtotal when single with foreign currency
+			if( group->showtotal == TRUE )
 			{
 				gtk_tree_store_append (GTK_TREE_STORE(model), &child_iter, &iter1);
 				gtk_tree_store_set (GTK_TREE_STORE(model), &child_iter,
@@ -425,10 +437,11 @@ GVariant *old_state, *new_state;
 		if( !strcmp("group", g_variant_get_string(new_state, NULL)) )
 			PREFS->pnl_acc_show_by = DSPACC_GROUP_BY_GROUP;
 
+	g_simple_action_set_state (action, new_state);
+	g_variant_unref (old_state);
+
 	ui_hub_account_populate(GLOBALS->mainwindow, NULL);
 
-  g_simple_action_set_state (action, new_state);
-  g_variant_unref (old_state);
 }
 
 
