@@ -110,7 +110,8 @@ struct hbfile_data *data;
 GtkTreeModel *model;
 GtkTreeIter  iter;
 GList *list;
-gint type, range;
+gint range;
+gboolean issubcat;
 guint n_result, i, n_items;
 GArray *garray;
 gdouble total, other;
@@ -120,10 +121,21 @@ Account *acc;
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
-	type  = hbtk_radio_button_get_active(GTK_CONTAINER(data->RA_type));
+
+GVariant *variant = g_action_group_get_action_state(G_ACTION_GROUP(data->action_group_top), "viewby");
+
+	DB( g_print(" new type is %s\n", g_variant_get_string (variant, NULL) ) );
+
+	issubcat = FALSE;
+	if( !strcmp("subcat", g_variant_get_string(variant, NULL)) )
+		issubcat = TRUE;
+
+	g_variant_unref(variant);
+
+	//type  = hbtk_radio_button_get_active(GTK_CONTAINER(data->RA_type));
 	range = hbtk_combo_box_get_active_id(GTK_COMBO_BOX_TEXT(data->CY_range));
 
-	DB( g_print(" - type=%d, range=%d\n", type, range) );
+	DB( g_print(" - range=%d\n", range) );
 	DB( g_print(" - pref range=%d\n", PREFS->date_range_wal) );
 
 	if(range == FLT_RANGE_OTHER)
@@ -189,7 +201,7 @@ Account *acc;
 					for(i=0;i<nbsplit;i++)
 					{
 						split = da_splits_get(ope->splits, i);
-						pos = category_report_id(split->kcat, type);
+						pos = category_report_id(split->kcat, issubcat);
 						if( pos <= garray->len )
 						{
 							trn_amount = hb_amount_base(split->amount, acc->kcur);
@@ -207,7 +219,7 @@ Account *acc;
 				{
 				struct tmptop *item;
 
-					pos = category_report_id(ope->kcat, type);
+					pos = category_report_id(ope->kcat, issubcat);
 					if( pos <= garray->len )
 					{
 						//#1297054 if( trn_amount < 0 ) {
@@ -326,11 +338,39 @@ Account *acc;
 }
 
 
+static void
+ui_hub_spending_activate_radio (GSimpleAction *action, GVariant *parameter, gpointer user_data)
+{
+//struct hbfile_data *data = user_data;
+GVariant *old_state, *new_state;
+
+	old_state = g_action_get_state (G_ACTION (action));
+	new_state = g_variant_new_string (g_variant_get_string (parameter, NULL));
+
+	DB( g_print ("Radio action %s activated, state changes from %s to %s\n",
+           g_action_get_name (G_ACTION (action)),
+           g_variant_get_string (old_state, NULL),
+           g_variant_get_string (new_state, NULL)) );
+
+	g_simple_action_set_state (action, new_state);
+	g_variant_unref (old_state);
+
+	ui_hub_spending_populate(GLOBALS->mainwindow, NULL);
+
+}
+
+
+
+static const GActionEntry actions[] = {
+//	name, function(), type, state, 
+	{ "viewby", ui_hub_spending_activate_radio ,  "s", "'cat'", NULL, {0,0,0} }
+};
+
 
 GtkWidget *ui_hub_spending_create(struct hbfile_data *data)
 {
 GtkWidget *hub, *hbox, *tbar;
-GtkWidget *label, *widget;
+GtkWidget *label, *widget, *image;
 GtkToolItem *toolitem;
 
 	DB( g_print("\n[hub-spendings] create\n") );
@@ -378,11 +418,46 @@ GtkToolItem *toolitem;
 	data->CY_range = make_daterange(label, DATE_RANGE_CUSTOM_HIDE);
 	gtk_box_pack_end (GTK_BOX (hbox), data->CY_range, FALSE, FALSE, 0);
 
-	widget = hbtk_radio_button_new(GTK_ORIENTATION_HORIZONTAL, CYA_CATSUBCAT, TRUE);
-	data->RA_type = widget;
-	gtk_box_pack_end (GTK_BOX (hbox), widget, FALSE, FALSE, 0);
+	//widget = hbtk_radio_button_new(GTK_ORIENTATION_HORIZONTAL, CYA_CATSUBCAT, TRUE);
+	//data->RA_type = widget;
+	//gtk_box_pack_end (GTK_BOX (hbox), widget, FALSE, FALSE, 0);
 
-	hbtk_radio_button_connect (GTK_CONTAINER(data->RA_type), "toggled", G_CALLBACK (ui_hub_spending_populate), NULL);
+	toolitem = gtk_separator_tool_item_new ();
+	gtk_tool_item_set_expand (toolitem, FALSE);
+	gtk_separator_tool_item_set_draw(GTK_SEPARATOR_TOOL_ITEM(toolitem), FALSE);
+	gtk_toolbar_insert(GTK_TOOLBAR(tbar), GTK_TOOL_ITEM(toolitem), -1);
+
+	//gmenu test (see test folder into gtk)
+GMenu *menu, *section;
+
+	menu = g_menu_new ();
+	section = g_menu_new ();
+	g_menu_append (section, _("Category")       , "actions.viewby::cat");
+	g_menu_append (section, _("Subcategory")    , "actions.viewby::subcat");
+	g_menu_append_section(menu, NULL, G_MENU_MODEL(section));
+	g_object_unref (section);
+
+
+	GSimpleActionGroup *group = g_simple_action_group_new ();
+	data->action_group_top = group;
+	g_action_map_add_action_entries (G_ACTION_MAP (group), actions, G_N_ELEMENTS (actions), data);
+
+
+	widget = gtk_menu_button_new();
+	gtk_menu_button_set_direction (GTK_MENU_BUTTON(widget), GTK_ARROW_UP);
+	gtk_widget_set_halign (widget, GTK_ALIGN_END);
+	image = gtk_image_new_from_icon_name (ICONNAME_EMBLEM_SYSTEM, GTK_ICON_SIZE_MENU);
+	g_object_set (widget, "image", image,  NULL);
+
+	toolitem = gtk_tool_item_new();
+	gtk_container_add (GTK_CONTAINER(toolitem), widget);
+	gtk_toolbar_insert(GTK_TOOLBAR(tbar), GTK_TOOL_ITEM(toolitem), -1);
+
+	gtk_widget_insert_action_group (widget, "actions", G_ACTION_GROUP(group));
+	gtk_menu_button_set_menu_model (GTK_MENU_BUTTON (widget), G_MENU_MODEL (menu));
+
+
+	//hbtk_radio_button_connect (GTK_CONTAINER(data->RA_type), "toggled", G_CALLBACK (ui_hub_spending_populate), NULL);
 
 	g_signal_connect (data->CY_range, "changed", G_CALLBACK (ui_hub_spending_populate), NULL);
 	
