@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2021 Maxime DOYEN
+ *  Copyright (C) 1995-2022 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -505,7 +505,7 @@ gboolean hastext = FALSE;
 		LST_DSPACC_DATAS, &acc,
 		-1);
 
-	// no tooltip is not an account
+	// no tooltip if not an account
 	if( (dt != DSPACC_TYPE_NORMAL) )
 	{
 		gtk_tree_path_free (path);
@@ -515,7 +515,7 @@ gboolean hastext = FALSE;
 	node = g_string_sized_new(255);
 	g_string_append(node, "<b>");
 	g_string_append(node, acc->name);
-	g_string_append(node, "</b>\n\n");
+	g_string_append(node, "</b>\n");
 
 	if( acc->rdate > 0 )
 	{
@@ -527,10 +527,10 @@ gboolean hastext = FALSE;
 		g_date_strftime (buffer, 256-1, PREFS->date_format, date);
 		g_date_free(date);
 		
-		g_string_append(node, buffer);
-		g_string_append(node, ", ");
-		g_string_append(node, _("last reconciled"));
 		g_string_append(node, "\n");
+		g_string_append(node, _("last reconciled"));
+		g_string_append(node, ": ");
+		g_string_append(node, buffer);
 		hastext = TRUE;
 	}
 
@@ -538,14 +538,15 @@ gboolean hastext = FALSE;
 	{
 	gchar formatd_buf[G_ASCII_DTOSTR_BUF_SIZE];
 
+		g_string_append(node, "\n");
 		hb_strfmon(formatd_buf, G_ASCII_DTOSTR_BUF_SIZE-1, acc->bal_today - acc->minimum, acc->kcur, FALSE);
 		g_string_append(node, formatd_buf);
-		g_string_append(node, ", ");
-		g_string_append(node, _("until"));
 		g_string_append(node, " ");
+		g_string_append(node, _("until overdraft"));
+		g_string_append(node, " (");
 		hb_strfmon(formatd_buf, G_ASCII_DTOSTR_BUF_SIZE-1, acc->minimum, acc->kcur, FALSE);
 		g_string_append(node, formatd_buf);
-		g_string_append(node, "\n");
+		g_string_append(node, ")");
 		hastext = TRUE;
 	}
 
@@ -553,14 +554,15 @@ gboolean hastext = FALSE;
 	{
 	gchar formatd_buf[G_ASCII_DTOSTR_BUF_SIZE];
 
+		g_string_append(node, "\n");
 		hb_strfmon(formatd_buf, G_ASCII_DTOSTR_BUF_SIZE-1, acc->maximum - acc->bal_today, acc->kcur, FALSE);
 		g_string_append(node, formatd_buf);
-		g_string_append(node, ", ");
-		g_string_append(node, _("before"));
 		g_string_append(node, " ");
+		g_string_append(node, _("before maximum"));
+		g_string_append(node, " (");
 		hb_strfmon(formatd_buf, G_ASCII_DTOSTR_BUF_SIZE-1, acc->maximum, acc->kcur, FALSE);
 		g_string_append(node, formatd_buf);
-		g_string_append(node, "\n");
+		g_string_append(node, ")");
 		hastext = TRUE;
 	}
 
