@@ -145,7 +145,9 @@ static   gint
 		case LST_DSPOPE_AMOUNT:
 		case LST_DSPOPE_EXPENSE:
 		case LST_DSPOPE_INCOME:
-			tmpval = ope1->amount - ope2->amount;
+			//tmpval = ope1->amount - ope2->amount;
+			//#1945636 amount sort in base currency
+			tmpval = hb_amount_base(ope1->amount, ope1->kcur) - hb_amount_base(ope2->amount, ope2->kcur);
 			retval = tmpval > 0 ? 1 : -1;
 			break;
 
