@@ -167,6 +167,30 @@ Payee *pay;
 }
 
 
+static void
+list_sch_category_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+{
+Archive *arc;
+gchar *text = NULL;
+
+	gtk_tree_model_get(model, iter, LST_DSPUPC_DATAS, &arc, -1);
+	if(arc)
+	{
+		if(arc->flags & OF_SPLIT)
+		{
+			text = _("- split -");
+		}
+		else
+		{
+		Category *cat = da_cat_get(arc->kcat);
+
+			text = (cat != NULL) ? cat->fullname : "";
+		}
+	}
+	g_object_set(renderer, "text", text, NULL);
+}
+
+
 static void 
 list_sch_memo_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
@@ -179,6 +203,7 @@ gint weight;
 		LST_DSPUPC_MEMO, &memo,
 		-1);
 
+	//to display total
 	weight = arc == NULL ? PANGO_WEIGHT_BOLD : PANGO_WEIGHT_NORMAL;
 
 	g_object_set(renderer, "weight", weight, "text", memo, NULL);
@@ -309,6 +334,12 @@ GtkTreeViewColumn *column;
 		PREFS->pnl_upc_col_pay_width = gtk_tree_view_column_get_fixed_width(column);
 	}
 	
+	column = list_upcoming_get_column(treeview, COL_DSPUPC_CATEGORY);
+	if( column )
+	{
+		PREFS->pnl_upc_col_cat_width = gtk_tree_view_column_get_fixed_width(column);
+	}
+
 	column = list_upcoming_get_column(treeview, COL_DSPUPC_MEMO);
 	if( column )
 	{
@@ -413,6 +444,29 @@ GtkTreeViewColumn *column;
 
 	gtk_tree_view_column_set_fixed_width(column, PREFS->pnl_upc_col_pay_width);
 
+	/* column: Category */
+	renderer = gtk_cell_renderer_text_new ();
+	g_object_set(renderer, 
+		"ellipsize", PANGO_ELLIPSIZE_END,
+		"ellipsize-set", TRUE,
+		//taken from nemo, not exactly a resize to content, but good compromise
+		"width-chars", 40,
+		NULL);
+	column = gtk_tree_view_column_new();
+	g_object_set_data(G_OBJECT(column), "uid", GUINT_TO_POINTER(COL_DSPUPC_CATEGORY));
+	gtk_tree_view_column_set_title(column, _("Category"));
+	gtk_tree_view_column_pack_start(column, renderer, TRUE);
+	gtk_tree_view_column_set_cell_data_func(column, renderer, list_sch_category_cell_data_function, NULL, NULL);
+	gtk_tree_view_column_set_resizable(column, TRUE);
+	//gtk_tree_view_column_add_attribute(column, renderer, "text", 1);
+	//gtk_tree_view_column_set_sort_column_id (column, LST_DSPACC_NAME);
+	gtk_tree_view_column_set_alignment (column, 0.5);
+	gtk_tree_view_column_set_min_width(column, HB_MINWIDTH_LIST/2);
+	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
+
+	gtk_tree_view_column_set_fixed_width(column, PREFS->pnl_upc_col_cat_width);
+
+	
 	/* column: Memo */
 	renderer = gtk_cell_renderer_text_new ();
 	g_object_set(renderer, 
