@@ -627,13 +627,25 @@ gint usrnbacc, usrrange;
 	if(g_list_length(data->ope_list) == 0)
 		goto end;
 
+	// update the date range if alldate is selected
+	if( (usrrange == FLT_RANGE_ALLDATE) )
+	{
+		data->filter->mindate = jmindate;
+		data->filter->maxdate = jmaxdate;
+		repbalance_update_quickdate(widget, NULL);
+	}
+	
 	// grab nb result and allocate memory
 	data->jbasedate = jmindate;
-	data->n_result = report_interval_count(tmpintvl, jmindate, jmaxdate);
+	//#1958001
+	data->n_result = report_interval_count(tmpintvl, data->filter->mindate, data->filter->maxdate);
 	data->tmp_income  = g_malloc0((data->n_result+2) * sizeof(gdouble));
 	data->tmp_expense = g_malloc0((data->n_result+2) * sizeof(gdouble));
 
-	DB( g_print(" %d days in selection, %d results", jmaxdate - jmindate, data->n_result) );
+	DB( g_print(" %d days in selection\n", data->filter->maxdate - data->filter->mindate));
+
+	DB( hb_print_date(data->filter->mindate, "min") );
+	DB( hb_print_date(data->filter->maxdate, "max") );
 
 	if(data->tmp_income && data->tmp_expense)
 	{
@@ -662,7 +674,7 @@ gint usrnbacc, usrrange;
 
 				if( (ope->date >= data->filter->mindate) && (ope->date <= data->filter->maxdate) )
 				{
-				gint pos = report_interval_get_pos(tmpintvl, data->jbasedate, ope);
+				gint pos = report_interval_get_pos(tmpintvl, data->filter->mindate, ope);
 
 					//deal with transactions
 					if(trn_amount < 0)
@@ -676,13 +688,6 @@ gint usrnbacc, usrrange;
 		}
 	}
 
-	// update the date range if alldate is selected
-	if( (usrrange == FLT_RANGE_ALLDATE) )
-	{
-		data->filter->mindate = jmindate;
-		data->filter->maxdate = jmaxdate;
-		repbalance_update_quickdate(widget, NULL);
-	}
 
 	// set currency
 	lst_repbal_set_cur(GTK_TREE_VIEW(data->LV_report), data->usrkcur);
@@ -696,7 +701,8 @@ gint usrnbacc, usrrange;
 	DB( g_print(" inserting %d results\n", data->n_result) );
 
 	gdouble balance = data->firstbalance;
-	for(i=0;i<=data->n_result;i++)
+	//#1958001
+	for(i=0;i<data->n_result;i++)
 	{
 	gboolean is_ovrdraft = FALSE;
 	gchar intvlname[64];
@@ -704,16 +710,18 @@ gint usrnbacc, usrrange;
 		balance += data->tmp_expense[i];
 		balance += data->tmp_income[i];
 
-		if(!showempty && data->tmp_expense[i] == 0 && data->tmp_income[i] == 0)
+		if( !showempty && (data->tmp_expense[i] == 0 && data->tmp_income[i] == 0) )
 			continue;
 
 		if(usrnbacc == 1)
 			is_ovrdraft = (balance < data->minimum) ? TRUE : FALSE;
 
 		//#1907699 date is wrong
-		//report_interval_snprint_name(intvlname, sizeof(intvlname)-1, tmpintvl, data->filter->mindate, i);
-		report_interval_snprint_name(intvlname, sizeof(intvlname)-1, tmpintvl, jmindate, i);
+		report_interval_snprint_name(intvlname, sizeof(intvlname)-1, tmpintvl, data->filter->mindate, i);
+		//report_interval_snprint_name(intvlname, sizeof(intvlname)-1, tmpintvl, jmindate, i);
 
+		DB( g_print(" %3d: %s %f %f\n", i, intvlname, data->tmp_expense[i], data->tmp_income[i]) );
+		
 		/* column 0: pos (gint) */
 		/* not used: column 1: key (gint) */
 		/* column 2: name (gchar) */
@@ -909,6 +917,9 @@ gint row;
 	//set the window icon
 	gtk_window_set_icon_name(GTK_WINDOW (window), ICONNAME_HB_REP_BALANCE);
 
+	//#1965594
+	gtk_window_set_transient_for (GTK_WINDOW (window), GTK_WINDOW (GLOBALS->mainwindow));
+
 	//window contents
 	mainvbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 	gtk_container_add (GTK_CONTAINER (window), mainvbox);
