@@ -1198,6 +1198,8 @@ gint row;
 	//set the window icon
 	gtk_window_set_icon_name(GTK_WINDOW (window), ICONNAME_HB_REP_BUDGET);
 
+	//#1965594
+	gtk_window_set_transient_for (GTK_WINDOW (window), GTK_WINDOW (GLOBALS->mainwindow));
 
 	//window contents
 	mainvbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
