@@ -128,6 +128,20 @@ gint retval = 0;
 				}
 			}
 			break;
+
+		case LST_DEFARC_SORT_CATEGORY:
+			{
+			Category *c1, *c2;
+
+				c1 = da_cat_get(item1->kcat);
+				c2 = da_cat_get(item2->kcat);
+				if( c1 != NULL && c2 != NULL )
+				{
+					retval = hb_string_utf8_compare(c1->fullname, c2->fullname);
+				}
+			}
+			break;
+
 		case LST_DEFARC_SORT_AMOUNT:
 			tmpval = item1->amount - item2->amount;
 			retval = tmpval > 0 ? 1 : -1;
@@ -211,41 +225,78 @@ GDate *date;
 }
 
 
-/*
-** draw some text from the stored data structure
-*/
 static void 
 list_tpl_cell_data_function_memo (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
-Archive *item;
+Archive *arc;
+gchar *text = NULL;
 
-	gtk_tree_model_get(model, iter, LST_DEFARC_DATAS, &item, -1);
-	g_object_set(renderer, "text", item->memo, NULL);
+	gtk_tree_model_get(model, iter, LST_DEFARC_DATAS, &arc, -1);
+	if(arc)
+	{
+		text = arc->memo;
+	}
+	g_object_set(renderer, "text", text, NULL);
 }
 
 
-
 static void
 list_tpl_cell_data_function_payee (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
 Archive *arc;
-Payee *pay;
-
-	gtk_tree_model_get(model, iter,
-		LST_DEFARC_DATAS, &arc,
-		-1);
+gchar *text = NULL;
 
+	gtk_tree_model_get(model, iter, LST_DEFARC_DATAS, &arc, -1);
 	if(arc)
 	{
-
-		pay = da_pay_get(arc->kpay);
+	Payee *pay = da_pay_get(arc->kpay);
 
 		if(pay != NULL)
-			g_object_set(renderer, "text", pay->name, NULL);
+			text = pay->name;
 	}
-	else
-		g_object_set(renderer, "text", NULL, NULL);
+	g_object_set(renderer, "text", text, NULL);
+}
 
+
+static void
+list_tpl_cell_data_function_category (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+{
+Archive *arc;
+gchar *text = NULL;
+
+	gtk_tree_model_get(model, iter, LST_DEFARC_DATAS, &arc, -1);
+	if(arc)
+	{
+		if(arc->flags & OF_SPLIT)
+		{
+			text = _("- split -");
+		}
+		else
+		{
+		Category *cat = da_cat_get(arc->kcat);
+
+			text = (cat != NULL) ? cat->fullname : "";
+		}
+	}
+	g_object_set(renderer, "text", text, NULL);
+}
+
+
+static void 
+list_tpl_cell_data_function_account (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+{
+Archive *arc;
+gchar *text = NULL;
+
+	gtk_tree_model_get(model, iter, LST_DEFARC_DATAS, &arc, -1);
+	if(arc)
+	{
+	Account *acc = da_acc_get(arc->kacc);
+
+		if(acc != NULL)
+			text = acc->name;
+	}
+	g_object_set(renderer, "text", text, NULL);
 }
 
 
@@ -292,24 +343,6 @@ gint weight;
 }
 
 
-static void 
-list_tpl_cell_data_function_account (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
-{
-Archive *arc;
-Account *acc;
-
-	gtk_tree_model_get(model, iter,
-		LST_DEFARC_DATAS, &arc,
-		-1);
-
-	acc = da_acc_get(arc->kacc);
-	if(acc != NULL)
-		g_object_set(renderer, "text", acc->name, NULL);
-	else
-		g_object_set(renderer, "text", NULL, NULL);
-}
-
-
 #if MYDEBUG == 1
 static void
 list_tpl_cell_data_function_debugkey (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
@@ -365,7 +398,7 @@ GtkCellRenderer    *renderer;
 static GtkWidget *list_tpl_new(void)
 {
 GtkListStore *store;
-GtkWidget *view;
+GtkWidget *treeview;
 GtkCellRenderer    *renderer;
 GtkTreeViewColumn  *column;
 
@@ -378,10 +411,10 @@ GtkTreeViewColumn  *column;
 		);
 
 	//treeview
-	view = gtk_tree_view_new_with_model(GTK_TREE_MODEL(store));
+	treeview = gtk_tree_view_new_with_model(GTK_TREE_MODEL(store));
 	g_object_unref(store);
 
-	gtk_tree_view_set_grid_lines (GTK_TREE_VIEW (view), PREFS->grid_lines);
+	gtk_tree_view_set_grid_lines (GTK_TREE_VIEW (treeview), PREFS->grid_lines);
 
 
 	#if MYDEBUG == 1
@@ -406,7 +439,7 @@ GtkTreeViewColumn  *column;
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
 	gtk_tree_view_column_set_cell_data_func(column, renderer, list_tpl_auto_cell_data_function, GINT_TO_POINTER(2), NULL);
 	
-	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
+	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 
 	/* column: Next on */
 	renderer = gtk_cell_renderer_text_new ();
@@ -417,15 +450,19 @@ GtkTreeViewColumn  *column;
 	gtk_tree_view_column_set_cell_data_func(column, renderer, list_tpl_date_cell_data_function, NULL, NULL);
 	gtk_tree_view_column_set_sort_column_id (column, LST_DEFARC_SORT_DATE);
 	gtk_tree_view_column_set_alignment (column, 0.5);
-	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
+	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 	
 	/* column: Payee */
 	column = list_tpl_column_text_create(_("Payee"), LST_DEFARC_SORT_PAYEE, list_tpl_cell_data_function_payee, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
+	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 
+	/* column: Category */
+	column = list_tpl_column_text_create(_("Category"), LST_DEFARC_SORT_CATEGORY, list_tpl_cell_data_function_category, NULL);
+	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
+	
 	/* column: Memo */
 	column = list_tpl_column_text_create(_("Memo"), LST_DEFARC_SORT_MEMO, list_tpl_cell_data_function_memo, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
+	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 	
 	/* column : amount */
 	column = gtk_tree_view_column_new();
@@ -436,16 +473,21 @@ GtkTreeViewColumn  *column;
 	gtk_tree_view_column_set_cell_data_func(column, renderer, list_tpl_amount_cell_data_function, NULL, NULL);
 	gtk_tree_view_column_set_sort_column_id (column, LST_DEFARC_SORT_AMOUNT);
 	gtk_tree_view_column_set_alignment (column, 0.5);
-	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
+	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 	
 	/* column : Account */
 	column = list_tpl_column_text_create(_("Account"), LST_DEFARC_SORT_ACCOUNT, list_tpl_cell_data_function_account, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
-	
+	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
+
+  	/* column : empty */
+	column = gtk_tree_view_column_new();
+	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
+
 	//sortable
 	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_DEFARC_SORT_DATE, list_tpl_compare_func, GINT_TO_POINTER(LST_DEFARC_SORT_DATE), NULL);
 	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_DEFARC_SORT_MEMO, list_tpl_compare_func, GINT_TO_POINTER(LST_DEFARC_SORT_MEMO), NULL);
 	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_DEFARC_SORT_PAYEE, list_tpl_compare_func, GINT_TO_POINTER(LST_DEFARC_SORT_PAYEE), NULL);
+	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_DEFARC_SORT_CATEGORY, list_tpl_compare_func, GINT_TO_POINTER(LST_DEFARC_SORT_CATEGORY), NULL);
 	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_DEFARC_SORT_AMOUNT, list_tpl_compare_func, GINT_TO_POINTER(LST_DEFARC_SORT_AMOUNT), NULL);
 	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_DEFARC_SORT_ACCOUNT, list_tpl_compare_func, GINT_TO_POINTER(LST_DEFARC_SORT_ACCOUNT), NULL);
 
@@ -454,7 +496,7 @@ GtkTreeViewColumn  *column;
 	//gtk_tree_view_set_headers_visible (GTK_TREE_VIEW(view), FALSE);
 	//gtk_tree_view_set_reorderable (GTK_TREE_VIEW(view), TRUE);
 
-	return(view);
+	return(treeview);
 }
 
 
