@@ -21,11 +21,14 @@
 #define __HB_ARCHIVE_GTK_H__
 
 
-#define LST_DEFARC_SORT_DATE    1
-#define LST_DEFARC_SORT_MEMO    2
-#define LST_DEFARC_SORT_PAYEE   3
-#define LST_DEFARC_SORT_AMOUNT  4
-#define LST_DEFARC_SORT_ACCOUNT 5
+enum {
+	LST_DEFARC_SORT_DATE = 1,
+	LST_DEFARC_SORT_MEMO,
+	LST_DEFARC_SORT_PAYEE,
+	LST_DEFARC_SORT_CATEGORY,
+	LST_DEFARC_SORT_AMOUNT,
+	LST_DEFARC_SORT_ACCOUNT
+};
 
 
 enum {
