@@ -1,5 +1,5 @@
 /*	HomeBank -- Free, easy, personal accounting for everyone.
- *	Copyright (C) 1995-2021 Maxime DOYEN
+ *	Copyright (C) 1995-2022 Maxime DOYEN
  *
  *	This file is part of HomeBank.
  *
@@ -2316,7 +2316,11 @@ gint w, h;
 	g_signal_connect (G_OBJECT (assistant), "cancel", G_CALLBACK (ui_import_assistant_close_cancel), assistant);
 	g_signal_connect (G_OBJECT (assistant), "close", G_CALLBACK (ui_import_assistant_close_cancel), assistant);
 	g_signal_connect (G_OBJECT (assistant), "apply", G_CALLBACK (ui_import_assistant_apply), NULL);
-	
+
+#ifdef G_OS_WIN32
+	hbtk_assistant_hack_button_order(assistant);
+#endif
+
 	gtk_widget_show (assistant);
 
 	if(PREFS->dtex_nointro)
