@@ -1,5 +1,5 @@
 /*	HomeBank -- Free, easy, personal accounting for everyone.
- *	Copyright (C) 1995-2021 Maxime DOYEN
+ *	Copyright (C) 1995-2022 Maxime DOYEN
  *
  *	This file is part of HomeBank.
  *
@@ -770,6 +770,10 @@ GtkWidget *assistant, *page;
 	g_signal_connect (G_OBJECT (assistant), "apply", G_CALLBACK (ui_newfile_assistant_apply), data);
 	g_signal_connect (G_OBJECT (assistant), "prepare", G_CALLBACK (ui_newfile_assistant_prepare), data);
 
+#ifdef G_OS_WIN32
+	hbtk_assistant_hack_button_order(assistant);
+#endif
+	
 	gtk_widget_show (assistant);
 
 	return assistant;
