@@ -1026,6 +1026,10 @@ static void ui_bud_manage_selection(GtkTreeSelection *treeselection, gpointer us
 
 static void ui_bud_manage_cb_type_changed (GtkToggleButton *button, gpointer user_data)
 {
+	//ignore event triggered from inactive radiobutton
+	if( gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button)) == FALSE )
+		return;
+
 	ui_bud_manage_populate_listview(user_data);
 	//g_print(" toggle type=%d\n", gtk_toggle_button_get_active(button));
 }
