@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2021 Maxime DOYEN
+ *  Copyright (C) 1995-2022 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -768,13 +768,43 @@ GtkWidget *dialog = NULL;
 /* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
 
 
-gint ui_dialog_export_csv(GtkWindow *parent, gchar **storage_ptr, gboolean *split_ptr, gboolean showall)
+struct dialog_export_csv_data
 {
+	gboolean  showall;
+	GtkWidget *dialog;
+	GtkWidget *CM_split, *CM_status;
+	GtkWidget *IM_warn, *LB_warn;
+};
+
+
+static void ui_dialog_export_csv_update(GtkWidget *widget, gpointer user_data)
+{
+struct dialog_export_csv_data *data = user_data;
+gboolean hassplit, hasstatus, visible;
+
+	hassplit  = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(data->CM_split));
+	hasstatus = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(data->CM_status));
+
+	visible = data->showall | hassplit | hasstatus;
+	hb_widget_visible(data->IM_warn, visible);
+	hb_widget_visible(data->LB_warn, visible);
+}
+
+
+gint ui_dialog_export_csv(GtkWindow *parent, gchar **storage_ptr, gboolean *split_ptr, gboolean *status_ptr, gboolean showall)
+{
+struct dialog_export_csv_data *data;
 GtkWidget *dialog, *content_area, *content_grid, *group_grid;
-GtkWidget *label, *widget, *BT_folder, *ST_name, *CM_split;
+GtkWidget *label, *widget, *BT_folder, *ST_name;
 gchar *tmpstr;
 gint crow, row;
 
+
+	data = g_malloc0(sizeof(struct dialog_export_csv_data));
+	if(!data) return GTK_RESPONSE_CANCEL;
+
+	data->showall = showall;
+	
 	dialog = gtk_dialog_new_with_buttons (_("Export as CSV"),
 		GTK_WINDOW (parent),
 		0,
@@ -783,7 +813,7 @@ gint crow, row;
 		NULL);
 
 	gtk_window_set_default_size (GTK_WINDOW(dialog), HB_MINWIDTH_LIST, -1);
-	
+
 	content_area = gtk_dialog_get_content_area(GTK_DIALOG (dialog));
 
 	content_grid = gtk_grid_new();
@@ -803,38 +833,45 @@ gint crow, row;
 
 	row++;
 	label = make_label_widget(_("Folder:"));
-	gtk_grid_attach (GTK_GRID (group_grid), label, 0, row, 1, 1);
+	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
 	BT_folder = gtk_file_chooser_button_new (_("Pick a Folder"), GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER);
-	gtk_grid_attach (GTK_GRID (group_grid), BT_folder, 1, row, 1, 1);
+	gtk_grid_attach (GTK_GRID (group_grid), BT_folder, 2, row, 1, 1);
 
 	row++;
 	label = make_label_widget(_("Filename:"));
-	gtk_grid_attach (GTK_GRID (group_grid), label, 0, row, 1, 1);
+	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
 	ST_name = make_string (label);
 	gtk_widget_set_hexpand(ST_name, TRUE);
-	gtk_grid_attach (GTK_GRID (group_grid), ST_name, 1, row, 1, 1);
+	gtk_grid_attach (GTK_GRID (group_grid), ST_name, 2, row, 1, 1);
 
 	row++;
-	CM_split = gtk_check_button_new_with_mnemonic (_("Detail split lines"));
-	gtk_grid_attach (GTK_GRID (group_grid), CM_split, 1, row, 1, 1);
+	label = make_label_group(_("Options"));
+	gtk_grid_attach (GTK_GRID (group_grid), label, 0, row, 3, 1);
 
-	if( showall )
-	{
+	row++;
+	data->CM_status = gtk_check_button_new_with_mnemonic (_("Add Status column"));
+	gtk_grid_attach (GTK_GRID (group_grid), data->CM_status, 1, row, 2, 1);
+	
+	row++;
+	data->CM_split = gtk_check_button_new_with_mnemonic (_("Detail split lines"));
+	gtk_grid_attach (GTK_GRID (group_grid), data->CM_split, 1, row, 2, 1);
 
-		row++;
-		/*
-		widget = gtk_image_new_from_icon_name (ICONNAME_WARNING, GTK_ICON_SIZE_DIALOG);
-		gtk_grid_attach (GTK_GRID (group_grid), widget, 0, row, 1, 1);
-		label = gtk_label_new("This feature is still in development state,\n(maybe not stable) so use it at your own risk!");
-		gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
-		*/
-		widget = gtk_image_new_from_icon_name (ICONNAME_WARNING, GTK_ICON_SIZE_DIALOG);
-		gtk_grid_attach (GTK_GRID (group_grid), widget, 0, row, 1, 1);
-		//                       123456789012345678901234567890123456789012345678901234567890
-		label = gtk_label_new(_("You export from 'Show all account', with the account column\n" \
-								"the file will not be in HomeBank CSV format."));
-		gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
-	}
+	//warning text
+	row++;
+	widget = gtk_image_new_from_icon_name (ICONNAME_WARNING, GTK_ICON_SIZE_DIALOG);
+	gtk_grid_attach (GTK_GRID (group_grid), widget, 1, row, 1, 1);
+	gtk_widget_set_margin_top (widget, SPACING_MEDIUM);
+	data->IM_warn = widget;
+	//                       123456789012345678901234567890123456789012345678901234567890
+	label = gtk_label_new(_("The file will not be in HomeBank CSV format, because you export\n" \
+							"from 'All transaction', or you selected an option."));
+	data->LB_warn = label;
+	gtk_grid_attach (GTK_GRID (group_grid), label, 2, row, 1, 1);
+
+	/* signals */
+	g_signal_connect (data->CM_split  , "toggled", G_CALLBACK (ui_dialog_export_csv_update), data);
+	g_signal_connect (data->CM_status , "toggled", G_CALLBACK (ui_dialog_export_csv_update), data);
+	
 
 	//setup
 	tmpstr = g_path_get_dirname(*storage_ptr);
@@ -847,7 +884,8 @@ gint crow, row;
 
 
 	gtk_widget_show_all(content_grid);
-
+	ui_dialog_export_csv_update(dialog, data);
+	
 	//wait for the user
 	gint result = gtk_dialog_run (GTK_DIALOG (dialog));
 
@@ -869,13 +907,21 @@ gint crow, row;
 		
 		if( split_ptr != NULL )
 		{
-			*split_ptr = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(CM_split));
+			*split_ptr = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(data->CM_split));
 		}
+
+		if( status_ptr != NULL )
+		{
+			*status_ptr = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(data->CM_status));
+		}
+		
 	}
 
 	// cleanup and destroy
 	gtk_widget_destroy (dialog);
 
+	g_free(data);
+	
 	return result;
 }
 
