@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2021 Maxime DOYEN
+ *  Copyright (C) 1995-2022 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -32,7 +32,7 @@ gboolean ui_file_chooser_csv(GtkWindow *parent, GtkFileChooserAction action, gch
 gboolean ui_file_chooser_xhb(GtkFileChooserAction action, gchar **storage_ptr, gboolean bakmode);
 gboolean ui_file_chooser_folder(GtkWindow *parent, gchar *title, gchar **storage_ptr);
 
-gint ui_dialog_export_csv(GtkWindow *parent, gchar **storage_ptr, gboolean *split, gboolean showall);
+gint ui_dialog_export_csv(GtkWindow *parent, gchar **storage_ptr, gboolean *split, gboolean *status, gboolean showall);
 gint ui_dialog_export_pdf(GtkWindow *parent, gchar **storage_ptr);
 
 void ui_dialog_upgrade_choose_currency(void);
