@@ -981,7 +981,7 @@ struct PayListContext context;
 
 	context.model = gtk_tree_view_get_model(GTK_TREE_VIEW(treeview));
 	context.needle = needle;
-	
+
 	gtk_list_store_clear (GTK_LIST_STORE(context.model));
 
 	//g_object_ref(model); /* Make sure the model stays with us after the tree view unrefs it */
@@ -1542,14 +1542,21 @@ GtkTreeIter iter;
 		Payee *newpay;
 		guint dstpaykey;
 
-			model = gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_pay));
-			gtk_list_store_clear (GTK_LIST_STORE(model));
 
 			dstpaykey = ui_pay_comboboxentry_get_key_add_new(GTK_COMBO_BOX(getwidget));
 
-			payee_move(srcpay->key, dstpaykey);
+			//do nothing if src = dst...
+			if( srcpay->key != dstpaykey)
+			{
 
-			newpay = da_pay_get(dstpaykey);
+				DB( g_print(" -> move pay to %d)\n", dstpaykey) );
+
+				model = gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_pay));
+				gtk_list_store_clear (GTK_LIST_STORE(model));
+
+				payee_move(srcpay->key, dstpaykey);
+
+				newpay = da_pay_get(dstpaykey);
 
 				//#1771720: update count
 				newpay->nb_use_all += srcpay->nb_use_all;
@@ -1557,23 +1564,30 @@ GtkTreeIter iter;
 				srcpay->nb_use_all = 0;
 				srcpay->nb_use_txn = 0;
 
-			// add the new payee to listview
-			if(newpay)
-				ui_pay_listview_add(GTK_TREE_VIEW(data->LV_pay), newpay);
+				// add the new payee to listview
+				if(newpay)
+					ui_pay_listview_add(GTK_TREE_VIEW(data->LV_pay), newpay);
 
-			// delete the old payee
-			if( gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(togglebutton)) )
-			{
-				DB( g_print(" -> delete %d '%s'\n", srcpay->key, srcpay->name ) );
+				// delete the old payee
+				if( gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(togglebutton)) )
+				{
+					DB( g_print(" -> delete %d '%s'\n", srcpay->key, srcpay->name ) );
 
-				ui_pay_listview_remove_selected(GTK_TREE_VIEW(data->LV_pay));
-				da_pay_delete(srcpay->key);
+					ui_pay_listview_remove_selected(GTK_TREE_VIEW(data->LV_pay));
+					da_pay_delete(srcpay->key);
+				}
+
+				data->change++;
+
+				//#1958767 if searchbar is active get the text
+				gchar *needle = NULL;
+				if( gtk_search_bar_get_search_mode(GTK_SEARCH_BAR(data->SB_search)) == TRUE )
+				{
+					needle = (gchar *)gtk_entry_get_text(GTK_ENTRY(data->ST_search));
+				}
+
+				ui_pay_listview_populate(data->LV_pay, needle);
 			}
-
-
-			data->change++;
-
-			ui_pay_listview_populate(data->LV_pay, NULL);
 		}
 
 		// cleanup and destroy
@@ -1668,18 +1682,20 @@ static void ui_pay_manage_dialog_onRowActivated (GtkTreeView        *treeview,
                        GtkTreeViewColumn  *col,
                        gpointer            user_data)
 {
-GtkTreeModel		 *model;
-GtkTreeIter			 iter;
+//GtkTreeModel		 *model;
+//GtkTreeIter			 iter;
 
 	DB( g_print("ui_pay_manage_dialog_onRowActivated()\n") );
 
-
-	model = gtk_tree_view_get_model(treeview);
-	gtk_tree_model_get_iter_first(model, &iter);
-	if(gtk_tree_selection_iter_is_selected(gtk_tree_view_get_selection(GTK_TREE_VIEW(treeview)), &iter) == FALSE)
-	{
+	//#1960743 double click payee not working after search
+	// no need to check is is not none here, done into edit
+	//model = gtk_tree_view_get_model(treeview);
+	//gtk_tree_model_get_iter_first(model, &iter);
+	//gtk_tree_model_get_iter(model, &iter, path);
+	//if(gtk_tree_selection_iter_is_selected(gtk_tree_view_get_selection(GTK_TREE_VIEW(treeview)), &iter) == FALSE)
+	//{
 		ui_pay_manage_dialog_edit(GTK_WIDGET(treeview), NULL);
-	}
+	//}
 }
 
 
@@ -1800,6 +1816,7 @@ gint w, h, dw, dh, row;
 	gtk_grid_attach (GTK_GRID (table), vbox, 0, row, 2, 1);
 
 	searchbar = gtk_search_bar_new();
+	data->SB_search = searchbar;
 	gtk_container_add(GTK_CONTAINER(vbox), searchbar);
 	widget = make_search();
 	gtk_widget_set_hexpand(widget, TRUE);
