@@ -546,12 +546,18 @@ static void deftransaction_cb_type_toggled(GtkWidget *widget, gpointer user_data
 struct deftransaction_data *data;
 gint type;
 
+	//ignore event triggered from inactive radiobutton
+	if( gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(widget)) == FALSE )
+		return;
+
 	DB( g_print("\n[ui-transaction] type change\n") );
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
 	type = hbtk_radio_button_get_active(GTK_CONTAINER(data->RA_type));
 
+	DB( g_print(" type:%d emit from '%s'\n", type, gtk_button_get_label(GTK_BUTTON(widget))) );
+
 	if( type == TXN_TYPE_INTXFER )
 	{
 		if( !(data->action == TXN_DLG_ACTION_EDIT) )
@@ -662,7 +668,6 @@ gint type, active;
 	value = gtk_spin_button_get_value(GTK_SPIN_BUTTON(data->ST_amount));
 	entry->amount = value;
 
-
 	//free any previous string
 	if(	entry->info )
 	{
@@ -1023,33 +1028,68 @@ Archive *entry1, *entry2;
 }
 
 
-
-
 static void ui_popover_tpl_populate(struct deftransaction_data *data, GList *srclist)
 {
 GtkTreeModel *model;
 GtkTreeIter  iter;
 GList *list;
+GString *tpltitle;
 
 	//insert all glist item into treeview
 	model  = data->model;
 	gtk_list_store_clear(GTK_LIST_STORE(model));
 
+	tpltitle = g_string_sized_new(255);
+	
 	list = g_list_first(srclist);
 	while (list != NULL)
 	{
-	Archive *entry = list->data;
+	Archive *item = list->data;
 
-		gtk_list_store_append (GTK_LIST_STORE(model), &iter);
-		gtk_list_store_set (GTK_LIST_STORE(model), &iter, 
-			LST_DSPTPL_DATAS, entry,
-			LST_DSPTPL_NAME, entry->memo,
-			 -1);
+		//#1968249 build a non empty label, when memo/payee/category are empty
+		g_string_truncate(tpltitle, 0);
+		if(item->memo != NULL)
+		{
+			g_string_append(tpltitle, item->memo);
+		}
+		else
+		{
+			g_string_append(tpltitle, _("(no memo)") );
+			if(item->kpay > 0)
+			{
+			Payee *pay = da_pay_get(item->kpay);
+
+				if(pay != NULL)
+				{
+					g_string_append_c(tpltitle, ' ');
+					g_string_append(tpltitle, pay->name);
+				}
+			}
+
+			if(item->kcat > 0)
+			{
+			Category *cat = da_cat_get(item->kcat);
+
+				if(cat != NULL)
+				{
+					g_string_append(tpltitle, " / ");
+					g_string_append(tpltitle, cat->fullname);
+				}
+			}
+
+		}
+		
+		gtk_list_store_insert_with_values(GTK_LIST_STORE(model), &iter, -1,
+			LST_DSPTPL_DATAS, item,
+			LST_DSPTPL_NAME, tpltitle->str,
+				-1);
 
 		//DB( g_print(" populate_treeview: %d %08x\n", i, list->data) );
 
 		list = g_list_next(list);
 	}
+
+	g_string_free(tpltitle, TRUE);
 }
 
 
