@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2021 Maxime DOYEN
+ *  Copyright (C) 1995-2022 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -98,6 +98,9 @@ void hbtk_radio_button_connect(GtkContainer *container, const gchar *detailed_si
 GtkWidget *hbtk_radio_button_new (GtkOrientation orientation, gchar **items, gboolean buttonstyle);
 GtkWidget *hbtk_radio_button_new_with_data (HbKivData *kivdata, gboolean buttonstyle);
 
+#ifdef G_OS_WIN32
+void hbtk_assistant_hack_button_order(GtkAssistant *assistant);
+#endif
 
 void gimp_label_set_attributes (GtkLabel *label, ...);
 
